-- -----------------------------------------------------------------------------
-- -----------------------------------------------------------------------------
--  Hammer of Justas
--
-- Copyright (C) 2010-2020
-- By Jonathan E. Wright
--
-- FILE: HoJ_DemonHunter.lua
-- DESC: Demon Hunter-specific functions and tables.

--[[
TODO:

BUGS:

NOTES:
--]]

local addonName, HoJ = ...

-- DEFAULT_CHAT_FRAME:AddMessage( "HoJ_DemonHunter.lua" )

local demonHunterSpellInfo = HoJ._demonHunterSpellInfos

-- -----------------------------------------------------------------------------
-- HoJ:DemonHunter_SelectSingleOrMultitarget
-- returns
--   rotationRules
--   interruptRules
--   mitigationRules
--   dpsCooldownRules
-- -----------------------------------------------------------------------------
function HoJ:DemonHunter_SelectSingleOrMultitarget( curSpecInfo, numAttackers )
    if ( self._numMeleeAttackers > curSpecInfo._multiTargetThreshold ) then
        return curSpecInfo._rotationRules._multiTarget, 
                curSpecInfo._interruptRules._multiTarget,
                curSpecInfo._mitigationRules._multiTarget,
                curSpecInfo._dpsCooldownRules._multiTarget
    else
        return curSpecInfo._rotationRules._singleTarget, 
                curSpecInfo._interruptRules._singleTarget,
                curSpecInfo._mitigationRules._singleTarget,
                curSpecInfo._dpsCooldownRules._singleTarget
    end
end

-- -----------------------------------------------------------------------------
-- HoJ:DemonHunter_Update
-- -----------------------------------------------------------------------------
function HoJ:DemonHunter_Update( time, curSpecInfo, updateCooldowns, updateBuffs, updateRotation )
    -- HoJ:DebugMsg( "Updating spec " .. specInfo._name );
    local rotationRules, interruptRules, mitigationRules, dpsCooldownRules = curSpecInfo._selectSingleOrMultiTargetFn( 
        HoJ, curSpecInfo,
        self._numMeleeAttackers )

    local rotationState = HoJ:ConstructCurrentRotationState( HoJ._curTime )

    -- update buffs
    if ( updateBuffs ) then
        local startBuffsMs = HoJ.ProfileBegin2( "Buffs" )
        
        HoJ:ClearIconList( HoJ._buffs );

        HoJ:CheckProcdBuffs( rotationState, curSpecInfo._activeBuffList, curSpecInfo._procdBuffList );
        --HoJ:Warrior_CheckBlessings( curSpecInfo._activeBlessings );

        HoJ.ProfileFunction( "UpdateIcons2:Buffs2:", HoJ.UpdateIcons2, self, time, HoJ._buffs, 
                curSpecInfo._buffSortPriorities, HoJ._buffFrames, true )

        HoJ.ProfileEnd( "Buffs", startBuffsMs )
    end

    -- update cooldowns
    if ( updateCooldowns ) then
        local startCooldownsMs = HoJ.ProfileBegin2( "Cooldowns" )

        HoJ.ProfileFunction( "ClearIconList", HoJ.ClearIconList, self, HoJ._cooldowns )

        HoJ.ProfileFunction( "CheckRules(dpsCooldowns)", HoJ.CheckRules, self, rotationState, 
                self._cooldowns, self._showCooldownsFrame, dpsCooldownRules, true, true )
        HoJ.ProfileFunction( "CheckRules(interrupts)", HoJ.CheckRules, self, rotationState,
                self._cooldowns, self._showCooldownsFrame, interruptRules, true, true )
        HoJ.ProfileFunction( "CheckRules(mitigations)", HoJ.CheckRules, self, rotationState,
                self._cooldowns, self._showCooldownsFrame, mitigationRules, true, true )

        HoJ.ProfileFunction( "UpdateIcons2:Cooldowns:", HoJ.UpdateIcons2, self, time, self._cooldowns, 
                curSpecInfo._cooldownSortPriorities, self._cooldownFrames, true )

        HoJ.ProfileEnd( "Cooldowns", startCooldownsMs )
    end

    -- update rotation
    if ( updateRotation ) then
        local startRotationMs = HoJ.ProfileBegin2( "Rotation" )

        HoJ:ClearIconList( HoJ._rotationSkills )

        HoJ:CheckDPSRotation( HoJ._rotationSkills, rotationRules )

        HoJ.ProfileFunction( "UpdateIcons2:Rotation:", HoJ.UpdateIcons2, self, time, HoJ._rotationSkills,
                { },  HoJ._rotationFrames, false );

        HoJ.ProfileEnd( "Rotation", startRotationMs )
    end    
end

--------------------------------------------------------------------------------
-- HAVOC
-- https://www.icy-veins.com/wow/havoc-demon-hunter-pve-dps-rotation-cooldowns-abilities
--------------------------------------------------------------------------------

local havocRotationRules = {
    _name = "havocRotationRules",
    {
        spellInfo = demonHunterSpellInfo.eyeBeam,
        -- _debugName = "eyeBeam",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.eyeBeam.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER, aConst = 1, bType = HoJ.TYPE_SKILL_POWER_COST, bConst = demonHunterSpellInfo.eyeBeam, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
            { aType = HoJ.TYPE_NUM_MELEE_ATTACKERS, aConst = 1, bType = HoJ.TYPE_CONSTANT, bConst = 2, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 3, bType = HoJ.TYPE_RESULT, bConst = 4, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.nemesis,
        -- _debugName = "nemesis",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.nemesis.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.bladeDance,
        -- _debugName = "bladeDance",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.bladeDance.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER, aConst = 1, bType = HoJ.TYPE_SKILL_POWER_COST, bConst = demonHunterSpellInfo.bladeDance, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
            { aType = HoJ.TYPE_NUM_MELEE_ATTACKERS, aConst = 1, bType = HoJ.TYPE_CONSTANT, bConst = 2, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_PLAYER_BUFF_ACTIVE, aConst = demonHunterSpellInfo.metamorphosisBuff, bType = HoJ.TYPE_CONSTANT, bConst = false, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 4, bType = HoJ.TYPE_RESULT, bConst = 5, op = HoJ.OP_AND },
            { aType = HoJ.TYPE_RESULT, aConst = 3, bType = HoJ.TYPE_RESULT, bConst = 6, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.deathSweep,
        -- _debugName = "deathSweep",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.deathSweep.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER, aConst = 1, bType = HoJ.TYPE_SKILL_POWER_COST, bConst = demonHunterSpellInfo.deathSweep, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
            { aType = HoJ.TYPE_NUM_MELEE_ATTACKERS, aConst = 1, bType = HoJ.TYPE_CONSTANT, bConst = 2, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_PLAYER_BUFF_ACTIVE, aConst = demonHunterSpellInfo.metamorphosisBuff, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 4, bType = HoJ.TYPE_RESULT, bConst = 5, op = HoJ.OP_AND },
            { aType = HoJ.TYPE_RESULT, aConst = 3, bType = HoJ.TYPE_RESULT, bConst = 6, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.immolationAura,
        -- _debugName = "immolationAura",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.immolationAura.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.fellblade,
        -- _debugName = "fellblade",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.fellblade.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER_AFTER_SKILL_USED, aConst = demonHunterSpellInfo.fellblade, bType = HoJ.TYPE_POWER_MAX, bConst = 1, op = HoJ.OP_LESS_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.eyeBeam,
        -- _debugName = "eyeBeam",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.eyeBeam.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER, aConst = 1, bType = HoJ.TYPE_SKILL_POWER_COST, bConst = demonHunterSpellInfo.eyeBeam, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.demonsBite,
        replacedByTalent = demonHunterSpellInfo.demonBlades,
        -- _debugName = "demonsBite",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.demonsBite.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER_AFTER_SKILL_USED, aConst = demonHunterSpellInfo.demonsBite, bType = HoJ.TYPE_POWER_MAX, bConst = 1, op = HoJ.OP_LESS_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.chaosStrike,
        -- _debugName = "chaosStrike",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.chaosStrike.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER, aConst = 1, bType = HoJ.TYPE_SKILL_POWER_COST, bConst = demonHunterSpellInfo.chaosStrike, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.felRush,
        -- _debugName = "felRush",
        tests = {
            { aType = HoJ.TYPE_SKILL_CHARGES, aConst = demonHunterSpellInfo.felRush, bType = HoJ.TYPE_CONSTANT, bConst = 1, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.felRush.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.throwGlaive,
        -- _debugName = "throwGlaive",
        tests = {
            { aType = HoJ.TYPE_SKILL_CHARGES, aConst = demonHunterSpellInfo.throwGlaive, bType = HoJ.TYPE_CONSTANT, bConst = 1, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.throwGlaive.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
}

local havocMitigationRules = {
    _name = "havocMitigationRules",
    {
        spellInfo = demonHunterSpellInfo.blur,
        -- _debugName = "blur",
        tests = {
            { aType = HoJ.TYPE_PLAYER_TIME_TO_LIVE, aConst = 0, bType = HoJ.TYPE_CONSTANT, bConst = 10.0, op = HoJ.OP_LESS },
            { aType = HoJ.TYPE_NET_INCOMING_DPS_CHR, aConst = 5.0, bType = HoJ.TYPE_PLAYER_HEALTH_RATIO, bConst = 0 , op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_OR },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.vengefulRetreat,
        -- _debugName = "vengefulRetreat",
        tests = {
            { aType = HoJ.TYPE_UNIT_IS_SLOWED, aConst = "player", bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
        }
    },
}

local havocInterruptRules = {
    _name = "havocInterruptRules",
    {
        spellInfo = demonHunterSpellInfo.disrupt,
        -- _debugName = "disrupt",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.disrupt.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_TARGET_CAN_BE_INTERRUPTED, aConst = 0, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
}

local havocDpsCooldownRules = {
    _name = "havocDpsCooldownRules",
    {
        spellInfo = demonHunterSpellInfo.metamorphosis,
        -- _debugName = "metamorphosis",
        tests = {
            { aType = HoJ.TYPE_COMBAT_TARGET_TIME_TO_LIVE, aConst = 1, bType = HoJ.TYPE_SPELL_DURATION, bConst = demonHunterSpellInfo.metamorphosis, op = HoJ.OP_GREATER },
            { aType = HoJ.TYPE_COMBAT_ATTACKS_HIT, aConst = 0, bType = HoJ.TYPE_CONSTANT, bConst = 1, op = HoJ.OP_GREATER },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
            { aType = HoJ.TYPE_TARGET_IS_TOUGH, aConst = 0, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 3, bType = HoJ.TYPE_RESULT, bConst = 4, op = HoJ.OP_OR },
            { aType = HoJ.TYPE_PLAYER_BUFF_ACTIVE, aConst = demonHunterSpellInfo.metamorphosisBuff, bType = HoJ.TYPE_CONSTANT, bConst = false, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 5, bType = HoJ.TYPE_RESULT, bConst = 6, op = HoJ.OP_AND },
        }
    },
}

local havocCooldownSortPriorities = {
    _name = "havocCooldownSortPriorities",
    [demonHunterSpellInfo.blur.id] = 4,
    [demonHunterSpellInfo.disrupt.id] = 3,
    [demonHunterSpellInfo.metamorphosis.id] = 2,
    [demonHunterSpellInfo.vengefulRetreat.id] = 1,
}

local havocActiveBuffList = { 
    [demonHunterSpellInfo.metamorphosisBuff.id] = HoJ:ConstructActiveBuff(),
    [demonHunterSpellInfo.blurBuff.id] = HoJ:ConstructActiveBuff(),
}

-- this is the list of buffs that we want to show on the buffs bar
-- in general we just show buffs that proc randomly here, or buffs with a stack count that needs tracking
local havocProcdBuffList = {
    { _spellInfo = demonHunterSpellInfo.metamorphosisBuff },
    { _spellInfo = demonHunterSpellInfo.blurBuff },
}

local havocActiveBlessingList = {
--[[
    [demonHunterSpellInfo.battleShout.id] = {
        spellInfo = demonHunterSpellInfo.battleShout,
        targetName = nil,
        start = 0.0,
        duration = 0.0,
        updateIndex = -1
    }
--]]
}

local havocBuffSortPriorities = {
    _name = "havocBuffSortPriorities",
    [demonHunterSpellInfo.metamorphosisBuff.id] = 2,
    [demonHunterSpellInfo.blurBuff.id] = 1,
}

--------------------------------------------------------------------------------
-- VENGEANCE
-- https://www.icy-veins.com/wow/vengeance-demon-hunter-pve-tank-rotation-cooldowns-abilities
--------------------------------------------------------------------------------

local vengeanceRotationRules = {
    _name = "vengeanceRotationRules",
    -- currently we have no way of knowing how many souls are active
--[[
    {
        spellInfo = demonHunterSpellInfo.spiritBomb,
        -- _debugName = "spiritBomb",
        tests = {
            { aType = HoJ.TYPE_CONSTANT, aConst = 1, bType = HoJ.TYPE_CONSTANT, bConst = 1, op = HoJ.OP_AND },
        }
    },
--]]
    {
        spellInfo = demonHunterSpellInfo.soulCleave,
        -- _debugName = "soulCleave",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.soulCleave .range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER, aConst = 1, bType = HoJ.TYPE_SKILL_POWER_COST, bConst = demonHunterSpellInfo.soulCleave, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.sigilOfFlame,
        -- _debugName = "sigilOfFlame",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.sigilOfFlame.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.shear,
        replacedByTalent = demonHunterSpellInfo.fracture,
        -- _debugName = "shear",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.shear.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.fracture,
        -- _debugName = "fracture",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.fracture.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER_AFTER_SKILL_USED, aConst = demonHunterSpellInfo.fracture, bType = HoJ.TYPE_POWER_MAX, bConst = 1, op = HoJ.OP_LESS_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
    -- SLREMOVE
--[[
    {
        spellInfo = demonHunterSpellInfo.vengeanceImmolationAura,
        -- _debugName = "immolationAura",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.vengeanceImmolationAura.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_POWER_AFTER_SKILL_USED, aConst = demonHunterSpellInfo.vengeanceImmolationAura, bType = HoJ.TYPE_POWER_MAX, bConst = 1, op = HoJ.OP_LESS_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
--]]
    {
        spellInfo = demonHunterSpellInfo.vengeanceThrowGlaive,
        -- _debugName = "throwGlaive",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.vengeanceThrowGlaive.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
        }
    },
}

local vengeanceMitigationRules = {
    _name = "vengeanceMitigationRules",
    {
        spellInfo = demonHunterSpellInfo.fieryBrand,
        -- _debugName = "fieryBrand",
        tests = {
            { aType = HoJ.TYPE_PLAYER_TIME_TO_LIVE, aConst = 0, bType = HoJ.TYPE_CONSTANT, bConst = 10.0, op = HoJ.OP_LESS },
            { aType = HoJ.TYPE_NET_INCOMING_DPS_CHR, aConst = 5.0, bType = HoJ.TYPE_PLAYER_HEALTH_RATIO, bConst = 0 , op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_OR },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.demonSpikes,
        -- _debugName = "demonSpikes",
        tests = {
            { aType = HoJ.TYPE_SKILL_CHARGES, aConst = demonHunterSpellInfo.demonSpikes, bType = HoJ.TYPE_CONSTANT, bConst = 1, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_PLAYER_BUFF_ACTIVE, aConst = demonHunterSpellInfo.demonSpikesBuff, bType = HoJ.TYPE_CONSTANT, bConst = false, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
            -- { aType = HoJ.TYPE_INCOMING_MAJOR_DAMAGE_SPELL, aConst = 0, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_CONSTANT, aConst = 1, bType = HoJ.TYPE_CONSTANT, bConst = 2, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_NET_INCOMING_DPS_PCT, aConst = 1.0, bType = HoJ.TYPE_CONSTANT, bConst = 0.25, op = HoJ.OP_GREATER_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 4, bType = HoJ.TYPE_RESULT, bConst = 5, op = HoJ.OP_OR },
            { aType = HoJ.TYPE_RESULT, aConst = 3, bType = HoJ.TYPE_RESULT, bConst = 6, op = HoJ.OP_AND },
        }
    },
}

local vengeanceInterruptRules = {
    _name = "vengeanceInterruptRules",
    {
        spellInfo = demonHunterSpellInfo.disrupt,
        -- _debugName = "disrupt",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.disrupt.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_TARGET_CAN_BE_INTERRUPTED, aConst = 0, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
    {
        spellInfo = demonHunterSpellInfo.imprison,
        -- _debugName = "imprison",
        tests = {
            { aType = HoJ.TYPE_TARGET_RANGE, aConst = demonHunterSpellInfo.imprison.range, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_SPELL_CREATURE_TYPES, aConst = demonHunterSpellInfo.imprison, bType = HoJ.TYPE_TARGET_CREATURE_TYPE, bConst = 1, op = HoJ.OP_TABLE_CONTAINS },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
        }
    },
}

local vengeanceDpsCooldownRules = {
    _name = "vengeanceDpsCooldownRules",
    {
        spellInfo = demonHunterSpellInfo.vengeanceMetamorphosis,
        -- _debugName = "metamorphosis",
        tests = {
            { aType = HoJ.TYPE_COMBAT_TARGET_TIME_TO_LIVE, aConst = 1, bType = HoJ.TYPE_SPELL_DURATION, bConst = demonHunterSpellInfo.vengeanceMetamorphosis, op = HoJ.OP_GREATER },
            { aType = HoJ.TYPE_COMBAT_ATTACKS_HIT, aConst = 0, bType = HoJ.TYPE_CONSTANT, bConst = 1, op = HoJ.OP_GREATER },
            { aType = HoJ.TYPE_RESULT, aConst = 1, bType = HoJ.TYPE_RESULT, bConst = 2, op = HoJ.OP_AND },
            { aType = HoJ.TYPE_TARGET_IS_TOUGH, aConst = 0, bType = HoJ.TYPE_CONSTANT, bConst = true, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 3, bType = HoJ.TYPE_RESULT, bConst = 4, op = HoJ.OP_OR },
            { aType = HoJ.TYPE_PLAYER_BUFF_ACTIVE, aConst = demonHunterSpellInfo.vengeanceMetamorphosisBuff, bType = HoJ.TYPE_CONSTANT, bConst = false, op = HoJ.OP_EQUAL },
            { aType = HoJ.TYPE_RESULT, aConst = 5, bType = HoJ.TYPE_RESULT, bConst = 6, op = HoJ.OP_AND },
        }
    },
}

local vengeanceCooldownSortPriorities = {
    _name = "vengeanceCooldownSortPriorities",
    [demonHunterSpellInfo.fieryBrand.id] = 5,
    [demonHunterSpellInfo.demonSpikes.id] = 4, 
    [demonHunterSpellInfo.disrupt.id] = 3,
    [demonHunterSpellInfo.imprison.id] = 2,
    [demonHunterSpellInfo.vengeanceMetamorphosis.id] = 1,
}

local vengeanceActiveBuffList = { 
    [demonHunterSpellInfo.vengeanceMetamorphosisBuff.id] = HoJ:ConstructActiveBuff(),
    [demonHunterSpellInfo.demonSpikesBuff.id] = HoJ:ConstructActiveBuff(),
    -- SLREMOVE
--[[
    [demonHunterSpellInfo.vengeanceImmolationAura.id] = HoJ:ConstructActiveBuff(),
--]]
    [demonHunterSpellInfo.soulFragments.id] = HoJ:ConstructActiveBuff(),
}

-- this is the list of buffs that we want to show on the buffs bar
-- in general we just show buffs that proc randomly here, or buffs with a stack count that needs tracking
local vengeanceProcdBuffList = {
    { _spellInfo = demonHunterSpellInfo.vengeanceMetamorphosisBuff },
    { _spellInfo = demonHunterSpellInfo.demonSpikesBuff },
    { _spellInfo = demonHunterSpellInfo.vengenceImmolationAura },
    { _spellInfo = demonHunterSpellInfo.soulFragments },
}

local vengeanceActiveBlessingList = {
--[[
    [demonHunterSpellInfo.battleShout.id] = {
        spellInfo = demonHunterSpellInfo.battleShout,
        targetName = nil,
        start = 0.0,
        duration = 0.0,
        updateIndex = -1
    }
--]]
}

local vengeanceBuffSortPriorities = {
    _name = "vengeanceBuffSortPriorities",
    [demonHunterSpellInfo.demonSpikesBuff.id] = 3,
    [demonHunterSpellInfo.soulFragments.id] = 2,
    [demonHunterSpellInfo.vengeanceMetamorphosisBuff.id] = 1,
}

local vengeanceAoeSpellTable = {
    [demonHunterSpellInfo.soulFragments.id] = {
        _buffId = demonHunterSpellInfo.soulFragments.id
    }
}

local vengeanceAoeBuffTable = {
    [demonHunterSpellInfo.soulFragments.id] = HoJ:ConstructAoeBuff( demonHunterSpellInfo.soulFragments, demonHunterSpellInfo.soulFragments )
}

HoJ[HoJ.CLASS_NAME_DEMONHUNTER] = {
    _spellInfos = HoJ._demonHunterSpellInfos,
    _className = HoJ.CLASS_NAME_DEMONHUNTER,
    _defaultSpecId = HoJ.SPEC_DEMONHUNTER_HAVOC,
    _powerColor = { r = 0.8, g = 0.0, b = 1.0, a = 1.0 },
    _usesComboPoints = false,
    [HoJ.SPEC_NAME_DEMONHUNTER_HAVOC] = {
        -- properties
        _name = HoJ._text["Havoc"],
        _spec = HoJ.SPEC_DEMONHUNTER_HAVOC,
        _role = HoJ.ROLE_DPS,
        _enabled = false,
        _multiTargetRange = 10,
        _multiTargetThreshold = 1,
        _minorHealHealthRatio = 0.9,
        _majorHealHealthRatio = 0.6,
        _defaultPowerPerSec = 10,
        _powerType = HoJ.POWER_TYPE_FURY,
        _autoPowerGen = false,
        _powerGainStep = 1,
        _powerMax = 100,
        _usesPowerPooling = false,
        -- functions
        _updateFn = HoJ.DemonHunter_Update,
        _updateRenderFn = nil,
        _resetFn = nil,
        _selectSingleOrMultiTargetFn = HoJ.DemonHunter_SelectSingleOrMultitarget,
        _nextSkillSelectFn = HoJ.NextSkillOffCooldown,
        _checkBlessingsFn = nil,
        _checkComboPointsFn = nil,
        _checkPowerFn = HoJ.CheckPower,
        -- tables
        _meleeAoESpells = nil,
        _activeBuffList = havocActiveBuffList,
        _procdBuffList = havocProcdBuffList,
        _activeBlessings = havocActiveBlessingList,
        _rotationRules = { _singleTarget = havocRotationRules, _multiTarget = havocRotationRules },
        _interruptRules = { _singleTarget = havocInterruptRules, _multiTarget = havocInterruptRules },
        _mitigationRules = { _singleTarget = havocMitigationRules, _multiTarget = havocMitigationRules },
        _dpsCooldownRules = { _singleTarget = havocDpsCooldownRules, _multiTarget = havocDpsCooldownRules },
        _cooldownSortPriorities = havocCooldownSortPriorities,
        _buffSortPriorities = havocBuffSortPriorities,
        _aoeSpellTable = nil,
        _aoeBuffTable = nil,
        _friendlyRangeSpells = {
            [HoJ.RANGE_MELEE] = nil,
            [HoJ.RANGE_8_YARDS] = nil,
            [HoJ.RANGE_10_YARDS] = nil,
            [HoJ.RANGE_12_YARDS] = nil,
            [HoJ.RANGE_20_YARDS] = nil,
            [HoJ.RANGE_25_YARDS] = nil,
            [HoJ.RANGE_30_YARDS] = nil,
            [HoJ.RANGE_40_YARDS] = nil,
            [HoJ.RANGE_100_YARDS] = {
                _spellInfo = demonHunterSpellInfo.demonsBite,
            },
        },
        _enemyRangeSpells = {
            [HoJ.RANGE_MELEE] = {
                _spellInfo = demonHunterSpellInfo.demonsBite
            },
            [HoJ.RANGE_8_YARDS] = {
                _spellInfo = demonHunterSpellInfo.demonsBite
            },
            [HoJ.RANGE_10_YARDS] = {
                _spellInfo = demonHunterSpellInfo.disrupt,
            },
            [HoJ.RANGE_12_YARDS] = {
                _spellInfo = demonHunterSpellInfo.disrupt,
            },
            [HoJ.RANGE_15_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.fellblade,
                    demonHunterSpellInfo.disrupt,
                }
            },
            [HoJ.RANGE_20_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.felRush,
                    demonHunterSpellInfo.fellblade,
                    demonHunterSpellInfo.disrupt,
                }
            },
            [HoJ.RANGE_25_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.felRush,
                    demonHunterSpellInfo.fellblade,
                    demonHunterSpellInfo.disrupt,
                }
            },
            [HoJ.RANGE_30_YARDS] = {
                _spellInfo = demonHunterSpellInfo.consumeMagic
            },
            [HoJ.RANGE_40_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.nemesis,
                    demonHunterSpellInfo.consumeMagic,
                }
            },
            [HoJ.RANGE_100_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.nemesis,
                    demonHunterSpellInfo.consumeMagic,
                }
            },
        },
    },
    [HoJ.SPEC_NAME_DEMONHUNTER_VENGEANCE] = {
        -- properties
        _name = HoJ._text["Vengeance"],
        _spec = HoJ.SPEC_DEMONHUNTER_VENGEANCE,
        _role = HoJ.ROLE_TANK,
        _enabled = false,
        _multiTargetRange = 10,
        _multiTargetThreshold = 1,
        _minorHealHealthRatio = 0.9,
        _majorHealHealthRatio = 0.6,
        _defaultPowerPerSec = 10,
        _powerType = HoJ.POWER_TYPE_PAIN,
        _autoPowerGen = false,
        _powerGainStep = 1,
        _powerMax = 100,
        _usesPowerPooling = false,
        -- functions
        _updateFn = HoJ.DemonHunter_Update,
        _updateRenderFn = nil,
        _resetFn = nil,
        _selectSingleOrMultiTargetFn = HoJ.DemonHunter_SelectSingleOrMultitarget,
        _nextSkillSelectFn = HoJ.NextSkillOffCooldown,
        _checkBlessingsFn = nil,
        _checkComboPointsFn = nil,
        _checkPowerFn = HoJ.CheckPower,
        -- tables
        _meleeAoESpells = nil,
        _activeBuffList = vengeanceActiveBuffList,
        _procdBuffList = vengeanceProcdBuffList,
        _activeBlessings = vengeanceActiveBlessingList,
        _rotationRules = { _singleTarget = vengeanceRotationRules, _multiTarget = vengeanceRotationRules },
        _interruptRules = { _singleTarget = vengeanceInterruptRules, _multiTarget = vengeanceInterruptRules },
        _mitigationRules = { _singleTarget = vengeanceMitigationRules, _multiTarget = vengeanceMitigationRules },
        _dpsCooldownRules = { _singleTarget = vengeanceDpsCooldownRules, _multiTarget = vengeanceDpsCooldownRules },
        _cooldownSortPriorities = vengeanceCooldownSortPriorities,
        _buffSortPriorities = vengeanceBuffSortPriorities,
        _aoeSpellTable = vengeanceAoeSpellTable,
        _aoeBuffTable = vengeanceAoeBuffTable,
        _friendlyRangeSpells = {
            [HoJ.RANGE_MELEE] = nil,
            [HoJ.RANGE_8_YARDS] = nil,
            [HoJ.RANGE_10_YARDS] = nil,
            [HoJ.RANGE_12_YARDS] = nil,
            [HoJ.RANGE_20_YARDS] = nil,
            [HoJ.RANGE_25_YARDS] = nil,
            [HoJ.RANGE_30_YARDS] = nil,
            [HoJ.RANGE_40_YARDS] = nil,
            [HoJ.RANGE_100_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.shear,
                    demonHunterSpellInfo.fracture,
                }
            },
        },
        _enemyRangeSpells = {
            [HoJ.RANGE_MELEE] = {
                _spellInfos = {
                    demonHunterSpellInfo.shear,
                    demonHunterSpellInfo.fracture,
                }
            },
            [HoJ.RANGE_8_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.shear,
                    demonHunterSpellInfo.fracture,
                }
            },
            [HoJ.RANGE_10_YARDS] = {
                _spellInfo = demonHunterSpellInfo.disrupt,
            },
            [HoJ.RANGE_12_YARDS] = {
                _spellInfo = demonHunterSpellInfo.disrupt,
            },
            [HoJ.RANGE_15_YARDS] = {
                _spellInfo = demonHunterSpellInfo.disrupt,
            },
            [HoJ.RANGE_20_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.imprison,
                    demonHunterSpellInfo.disrupt,
                }
            },
            [HoJ.RANGE_25_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.imprison,
                    demonHunterSpellInfo.disrupt,
                }
            },
            [HoJ.RANGE_30_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.consumeMagic,
                    demonHunterSpellInfo.fieryBrand
                }
            },
            [HoJ.RANGE_40_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.consumeMagic,
                    demonHunterSpellInfo.fieryBrand
                }
            },
            [HoJ.RANGE_100_YARDS] = {
                _spellInfos = {
                    demonHunterSpellInfo.consumeMagic,
                    demonHunterSpellInfo.fieryBrand
                }
            },
        },
    },
}

-- -----------------------------------------------------------------------------
-- HoJ:LoadDemonHunter
-- -----------------------------------------------------------------------------
function HoJ:LoadDemonHunter()
    if ( HoJ._classId ~= HoJ.CLASS_ID_DEMONHUNTER ) then
        HoJ:Error( "LoadDemonHunter called but _classId is not demon hunter!" )
    end

    HoJ.SpellInfo = HoJ._demonHunterSpellInfos
end
