-- -----------------------------------------------------------------------------
-- -----------------------------------------------------------------------------
--  Hammer of Justas
--
-- Copyright (C) 2010-2020
-- By Jonathan E. Wright
--
-- FILE: HoJ_Profile.lua
-- DESC: Addon profiling and debugging functions.

local addonName, HoJ = ...

-- DEFAULT_CHAT_FRAME:AddMessage( "HoJ_Profile.lua" )

-- ============================================================================


-- ============================================================================
-- Profiling

HoJ._profileTable = { }
HoJ._profileFrameNum = 0
HoJ._enableProfiling = false
HoJ._profileThreshold = 0.3 -- threshold in ms before showing CPU time
HoJ._profileFunction = nil

-- ----------------------------------------------------------------------------
-- HoJ.ProfileBegin
-- ----------------------------------------------------------------------------

function HoJ.ProfileBegin( name_, key )
	if ( HoJ._profileTable[key] == nil ) then
		HoJ._profileTable[key] = { name = name_, startMs = 0.0, endMs = 0.0, timeMs = 0.0, count = 0 }
	end
	HoJ._profileTable[key].startMs = debugprofilestop()
end

-- ----------------------------------------------------------------------------
-- HoJ.ProfileBegin2
-- ----------------------------------------------------------------------------
function HoJ.ProfileBegin2( name )
	HoJ.ProfileBegin( name, name )
end

-- ----------------------------------------------------------------------------
-- HoJ.ProfileEnd
-- ----------------------------------------------------------------------------
function HoJ.ProfileEnd( key, startTime, spam )
	local endMs = debugprofilestop()

	local entry = HoJ._profileTable[key]
	entry.endMs = endMs
	entry.timeMs = entry.endMs - entry.startMs
	entry.count = entry.count + 1
	entry.frameNum = HoJ._profileFrameNum
	if ( spam ~= nil ) then
		DEFAULT_CHAT_FRAME:AddMessage( "ProfileEnd( " .. HoJ._profileFrameNum .. " ): " .. key .. " = " .. entry.timeMs .. " ms" );
	end
end

-- ----------------------------------------------------------------------------
-- HoJ.ProfileFunction
-- ----------------------------------------------------------------------------

function HoJ.ProfileFunction( name, func, ... )
	local startTime = HoJ.ProfileBegin( name, name )
	func( ... )
	HoJ.ProfileEnd( name, startTime )
end

-- ----------------------------------------------------------------------------
-- HoJ.ProfileFunction
-- ----------------------------------------------------------------------------
function HoJ.ProfileClear( name )
	local entry = HoJ._profileTable[name]
	entry.timeMs = 0
end
