-- -----------------------------------------------------------------------------
-- -----------------------------------------------------------------------------
--  Hammer of Justas
--
-- Copyright (C) 2010-2020
-- By Jonathan E. Wright
--
-- FILE: HoJ_UI.lua
-- DESC: Addon user interface.

local addonName, HoJ = ...

-- DEFAULT_CHAT_FRAME:AddMessage( "HoJ_UI.lua" )

local SCROLLBAR_WIDTH = 16
local SCROLLBAR_HEIGHT = 12
local EDGE_SIZE = 8

local sliderBackdrop  = {
	bgFile = "Interface\\Buttons\\UI-SliderBar-Background",
	edgeFile = "Interface\\Buttons\\UI-SliderBar-Border",
	tile = true, tileSize = 8, edgeSize = 8,
	insets = { left = 3, right = 3, top = 6, bottom = 6 }
};

local listBackdrop = {
  -- path to the background texture
  bgFile = "Interface\\Buttons\\UI-SliderBar-Background",
  -- path to the border texture
  edgeFile = "Interface/Buttons/UI-SliderBar-Border",
  -- true to repeat the background texture to fill the frame, false to scale it
  tile = true,
  -- size (width or height) of the square repeating background tiles (in pixels)
  tileSize = 8,
  -- thickness of edge segments and square size of edge corners (in pixels)
  edgeSize = EDGE_SIZE,
  -- distance from the edges of the frame to those of the background texture (in pixels)
  insets = {
	left = 3,
	right = 3,
	top = 3,
	bottom = 3
  }
};

function SetBackdrop( frame, def )
	frame.backdrop = frame:CreateTexture()
	frame.backdrop:SetAllPoints( frame )
	frame.backdrop:SetTexture(def.bgFile)
end

-- -----------------------------------------------------------------------------
-- HoJ:AddonOptions_OnOK
-- -----------------------------------------------------------------------------
function HoJ:AddonOptions_OnOK()
	HoJ:CreateSavedVariablesFromHoJ( "Changes saved." )
end

-- -----------------------------------------------------------------------------
-- HoJ:AddonOptions_OnCancel
-- -----------------------------------------------------------------------------
function HoJ:AddonOptions_OnCancel()
	HoJ:RestoreSavedVariables()
end

-- -----------------------------------------------------------------------------
-- HoJ:AddonOptions_OnDefault
-- -----------------------------------------------------------------------------
function HoJ:AddonOptions_OnDefault()
	--HoJ:DebugMsg( "AddonOptions_OnDefault" );
end

-- -----------------------------------------------------------------------------
-- HoJ:AddonOptions_OnRefresh
-- -----------------------------------------------------------------------------
function HoJ:AddonOptions_OnRefresh()
	--HoJ:DebugMsg( "AddonOptions_OnRefresh" );
end

-- -----------------------------------------------------------------------------
-- HoJ:ToggleShowSpellOnBar
-- -----------------------------------------------------------------------------
function HoJ:ToggleShowSpellOnBar( spell )
	spell.showOnBar = not spell.showOnBar
end

-- -----------------------------------------------------------------------------
-- HoJ:ToggleShowSkillSFrame
-- -----------------------------------------------------------------------------
function HoJ:ToggleShowSkillSFrame()
	HoJ._showCooldownsFrame = not HoJ._showCooldownsFrame
end

-- -----------------------------------------------------------------------------
-- HoJ:ToggleShowBuffsFrame
-- -----------------------------------------------------------------------------
function HoJ:ToggleShowBuffsFrame()
	HoJ._showBuffsFrame = not HoJ._showBuffsFrame
end

-- -----------------------------------------------------------------------------
-- HoJ:ToggleShowRotationFrame
-- -----------------------------------------------------------------------------
function HoJ:ToggleShowRotationFrame()
	HoJ._showRotationFrame = not HoJ._showRotationFrame
end

-- -----------------------------------------------------------------------------
-- HoJ:ToggleShowRotationSecondaryFrame
-- -----------------------------------------------------------------------------
function HoJ:ToggleShowRotationSecondaryFrame()
	HoJ._showRotationSecondaryFrame = not HoJ._showRotationSecondaryFrame
end

-- -----------------------------------------------------------------------------
-- HoJ:TogglehowTemplarsVerdictFrame
-- -----------------------------------------------------------------------------
function HoJ:ToggleShowTemplarsVerdictFrame()
	HoJ._showTemplarsVerdictFrame = not HoJ._showTemplarsVerdictFrame
end

-- -----------------------------------------------------------------------------
-- HoJ:ToggleShowHolyPowerFrame
-- -----------------------------------------------------------------------------
function HoJ:ToggleShowHolyPowerFrame()
	HoJ._showHolyPowerFrame = not HoJ._showHolyPowerFrame
end

-- -----------------------------------------------------------------------------
-- HoJ:ToggleEnableForSpec
-- -----------------------------------------------------------------------------
function HoJ:ToggleEnableForSpec( className, specName ) 
	local enabled = HoJ[className][specName]._enabled
	HoJ[className][specName]._enabled = not enabled
end

-- -----------------------------------------------------------------------------
-- HoJ:ToggleShowDebugFrame
-- -----------------------------------------------------------------------------
function HoJ:ToggleShowDebugFrame()
	HoJ._showDebugFrame = not HoJ._showDebugFrame
	--HoJ:DebugMsg( "_showDebugFrame = " .. tostring( HoJ._showDebugFrame ) )
end

-- -----------------------------------------------------------------------------
-- HoJ:SetupCheckBox
-- -----------------------------------------------------------------------------
function HoJ:SetupCheckBox( parentFrame, anchorFrame, name, anchor1, anchor2, xoffset, yoffset, checked, fontSize, text )
	local cb = CreateFrame( "CheckButton", name, parentFrame, "OptionsCheckButtonTemplate" )
	cb:SetPoint( anchor1, anchorFrame, anchor2, xoffset, yoffset )
	--cb:SetScript( "OnClick", function ( self ) HoJ:ToggleShowSpellOnBar( spellInfo ) end )
	cb:SetChecked( checked )
	-- the following is really pretty stupid and was a PITA to figure out
	--getglobal( cb:GetName() .. 'Text' ):SetFont( "Fonts\\FRIZQT__.TTF", fontSize )
	getglobal( cb:GetName() .. 'Text' ):SetText( text )
	return cb;
end

-- -----------------------------------------------------------------------------
-- HoJ:GetCheckWidthWithText
-- -----------------------------------------------------------------------------
function HoJ:GetCheckWidthWithText( cb)
	local textWidth = getglobal( cb:GetName() .. 'Text' ):GetWidth()
	return textWidth + cb:GetWidth()
end

function HoJ_FormatSpell( spellInfo, text, spellTypeName )
	if ( spellInfo._talentSpecs == nil or spellInfo._classId == nil ) then
		formatString = text .. " (" .. spellTypeName .. ")"
		return formatString
	end

	local className = HoJ._classIdToClassName[spellInfo._classId]
	local specs = HoJ._specIdToSpecName[className]
	local locale = HoJ._text
	local count = 0
	specNames = ""
	for k, spec in pairs( spellInfo._talentSpecs ) do
		if ( count > 0 ) then
			specNames = ", " .. specNames .. specs[locale[spec]]
		else
			specNames = specNames .. specs[locale[spec]]
		end
	end

	return text .. " (" .. spellTypeName .. " - " .. specNames .. ")"
end

-- -----------------------------------------------------------------------------
-- HoJ:SetupSpellCheckBox
-- -----------------------------------------------------------------------------
function HoJ:SetupSpellCheckBox( parentFrame, anchorFrame, name, anchor1, anchor2, xoffset, yoffset, fontSize, spellInfo, text )
	local cb = CreateFrame( "CheckButton", name, parentFrame, "OptionsCheckButtonTemplate" );
	cb:SetPoint( anchor1, anchorFrame, anchor2, xoffset, yoffset );
	cb:SetScript( "OnClick", function ( self ) HoJ:ToggleShowSpellOnBar( spellInfo ) end );
	cb:SetChecked( spellInfo.showOnBar );
	--getglobal( cb:GetName() .. 'Text' ):SetFont( "Fonts\\FRIZQT__.TTF", fontSize );
	-- the following is really pretty stupid and was a PITA to figure out
	if ( spellInfo.spellType == HoJ.SPELL_BUFF 
		or spellInfo.spellType == HoJ.SPELL_TALENT_BUFF 
		or spellInfo.spellType == HoJ.SPELL_SKILL_BUFF ) then
		getglobal( cb:GetName() .. 'Text' ):SetText( HoJ_FormatSpell( spellInfo, text, "Buff" ) )
	elseif ( spellInfo.spellType == HoJ.SPELL_SKILL ) then
		getglobal( cb:GetName() .. 'Text' ):SetText( HoJ_FormatSpell( spellInfo, text, "Skill" ) )
	elseif ( spellInfo.spellType == HoJ.SPELL_TALENT ) then
		getglobal( cb:GetName() .. 'Text' ):SetText( HoJ_FormatSpell( spellInfo, text, "Talent" ) )
	elseif ( spellInfo.spellType == HoJ.SPELL_SHAPESHIFT ) then
		getglobal( cb:GetName() .. 'Text' ):SetText( HoJ_FormatSpell( spellInfo, text, "Seal" ) )
	else
		getglobal( cb:GetName() .. 'Text' ):SetText( text )
	end
	return cb;
end

-- -----------------------------------------------------------------------------
-- HoJ:SetupShowSpellCheckBox
-- -----------------------------------------------------------------------------
function HoJ:SetupShowSpellCheckBox( parentFrame, anchorFrame, name, anchor1, 
		anchor2, xoffset, yoffset, fontSize, spellInfo, count )
	return HoJ:SetupSpellCheckBox( parentFrame, anchorFrame, name, anchor1, 
		anchor2, xoffset, yoffset, fontSize, spellInfo, HoJ._text["SHOW"] .. spellInfo.name );
end

-- -----------------------------------------------------------------------------
-- HoJ:OnScrollValueChanged
-- -----------------------------------------------------------------------------
function HoJ:OnScrollValueChanged( slider, value )
	-- HoJ:DebugMsg( "OnScrollValueChanged(): slider = " .. slider.name .. ", value = " .. value )
	slider.scrollView:SetVerticalScroll( value )
	slider.scrollView:UpdateScrollChildRect()
	local itemFrame = slider.scrollView:GetScrollChild()
	-- HoJ:DebugMsg( "OnScrollValueChanged: itemFrame = " .. itemFrame:GetName() )
	itemFrame:SetPoint( "TOPLEFT", slider.scrollView, "TOPLEFT", 0, value )
	itemFrame:SetPoint( "TOPRIGHT", slider.scrollView, "TOPRIGHT", 0, value )
end

-- -----------------------------------------------------------------------------
-- scrollView_OnMouseWheel
-- -----------------------------------------------------------------------------
local function scrollView_OnMouseWheel( self, delta )
	local cur = self.slider:GetValue();
	local min, max = self.slider:GetMinMaxValues();
	local new = cur + ( delta * -1 * self.itemHeight );
	if ( new < min ) then
		new = min;
	elseif ( new > max ) then
		new = max;
	end
	self.slider:SetValue( new );
end

-- -----------------------------------------------------------------------------
-- Clamp
-- -----------------------------------------------------------------------------
 local function Clamp( value, min, max )
 	if ( value < min ) then
 		return min
 	elseif ( value > max ) then
 		return max
 	end

 	return value
 end

-- -----------------------------------------------------------------------------
-- HoJ:OnGlobalAlphaChanged
-- -----------------------------------------------------------------------------
function HoJ:OnGlobalAlphaChanged( alphaSlider, value )
	self._globalAlpha = Clamp( value, 0.1, 1.0 )

	HoJFrame_Rotation:SetAlpha( self._globalAlpha * HoJ._rotationAlpha )
	HoJFrame_Cooldowns:SetAlpha( self._globalAlpha * HoJ._cooldownsAlpha )
	HoJFrame_Buffs:SetAlpha( self._globalAlpha * HoJ._buffsAlpha )
	-- holy power alpha is always set dynamically
	--HoJFrame_HoPo:SetAlpha( self._globalAlpha * HoJ._holyPowerAlpha )
	--HoJFrame:SetAlpha( self._globalAlpha * HoJ._holyPowerAlpha )

	--self:DebugMsg( "UI alpha = " .. self._globalAlpha )
end

-- -----------------------------------------------------------------------------
-- HoJ:OnRotationAlphaChanged
-- -----------------------------------------------------------------------------
function HoJ:OnRotationAlphaChanged( alphaSlider, value )
	self._rotationAlpha = Clamp( value, 0.1, 1.0 )
	HoJFrame_Rotation:SetAlpha( self._globalAlpha * HoJ._rotationAlpha )
	--self:DebugMsg( "Rotation alpha = " .. self._rotationAlpha )
end

-- -----------------------------------------------------------------------------
-- HoJ:OnRotationSecondaryAlphaChanged
-- -----------------------------------------------------------------------------
function HoJ:OnRotationSecondaryAlphaChanged( alphaSlider, value )
	self._rotationSecondaryAlpha = Clamp( value, 0.1, 1.0 )
	HoJ_RotationSecondaryFrame:SetAlpha( self._globalAlpha * HoJ._rotationSecondaryAlpha )
	--self:DebugMsg( "Rotation alpha = " .. self._rotationSecondaryAlpha )
end

-- -----------------------------------------------------------------------------
-- HoJ:OnCooldownsAlphaChanged
-- -----------------------------------------------------------------------------
function HoJ:OnCooldownsAlphaChanged( alphaSlider, value )
	self._cooldownsAlpha = Clamp( value, 0.1, 1.0 )
	HoJFrame_Cooldowns:SetAlpha( self._globalAlpha * HoJ._cooldownsAlpha )
	--self:DebugMsg( "Cooldowns alpha = " .. self._cooldownsAlpha )
end

-- -----------------------------------------------------------------------------
-- HoJ:OnBuffsAlphaChanged
-- -----------------------------------------------------------------------------
function HoJ:OnBuffsAlphaChanged( alphaSlider, value )
	self._buffsAlpha = Clamp( value, 0.1, 1.0 )
	HoJFrame_Buffs:SetAlpha( self._globalAlpha * HoJ._buffsAlpha )
	--self:DebugMsg( "Buffs alpha = " .. self._buffsAlpha )
end

-- -----------------------------------------------------------------------------
-- HoJ:OnHolyPowerAlphaChanged
-- -----------------------------------------------------------------------------
function HoJ:OnHolyPowerAlphaChanged( alphaSlider, value )
	self._holyPowerAlpha = Clamp( value, 0.1, 1.0 )
	-- holy power alphas are updated dynamically each frame
	--HoJFrame_HoPo:SetAlpha( self._globalAlpha * HoJ._holyPowerAlpha )
	--HoJFrame:SetAlpha( self._globalAlpha * HoJ._holyPowerAlpha )
	--self:DebugMsg( "Holy Power alpha = " .. self._holyPowerAlpha )
end

-- -----------------------------------------------------------------------------
-- HoJ:OnDebugAlphaChanged
-- -----------------------------------------------------------------------------
function HoJ:OnDebugAlphaChanged( alphaSlider, value )
	self._debugAlpha = Clamp( value, 0.1, 1.0 )
	HoJFrame_Debug:SetAlpha( self._globalAlpha * HoJ._debugAlpha )
	--self:DebugMsg( "value = " .. value .. ", debug alpha = " .. self._debugAlpha )
end

-- -----------------------------------------------------------------------------
-- HoJ:AddSlider
-- -----------------------------------------------------------------------------
function HoJ:AddSlider( name, title, parent, relativeFrame, relativeTo, ofsx, ofsy, width, height, min, max, fontSize, minText, maxText, value, callbackFn )
	local sl = CreateFrame( "Slider", name, parent, "OptionsSliderTemplate")
	--sl.name = "UI Alpha"
	sl:SetOrientation( "HORIZONTAL" )
	sl:SetHitRectInsets( 0, 0, -10, 0 )
	sl:SetThumbTexture( "Interface\\Buttons\\UI-SliderBar-Button-Horizontal" )
	sl.slider = sl
	sl:SetPoint( "TOPLEFT", relativeFrame, relativeTo, ofsx, ofsy )
	sl:SetWidth( width )
	sl:SetHeight( height )
	sl:SetScript( "OnValueChanged", callbackFn )
	sl:SetMinMaxValues( min, max )
	sl:SetValueStep( 1 )
	sl:SetValue( value )

	local lowText = getglobal( sl:GetName() .. "Low" )
	lowText:SetFont( "Fonts\\FRIZQT__.TTF", fontSize );
	lowText:SetText( minText )

	local highText = getglobal( sl:GetName() .. "High" )
	highText:SetFont( "Fonts\\FRIZQT__.TTF", fontSize );
 	highText:SetText( maxText )

	local titleText = getglobal( sl:GetName() .. "Text" )
	titleText:SetFont( "Fonts\\FRIZQT__.TTF", fontSize );
 	titleText:SetText( title )
 	return sl
 end

  -- -----------------------------------------------------------------------------
-- HoJ:AddHorizontalSlider
-- -----------------------------------------------------------------------------
function HoJ:AddHorizontalSlider( name, title, parent, relativeFrame, relativeTo, ofsx, ofsy, width, height, min, max, fontSize, minText, maxText, value, callbackFn )
	local sl = CreateFrame( "Slider", name, parent, "OptionsSliderTemplate")

	local titleText = getglobal( sl:GetName() .. "Text" )
	titleText:SetFont( "Fonts\\FRIZQT__.TTF", fontSize );
	titleText:SetText( title .. " : " .. maxText )
	--local titleTextWidth = titleText:GetWidth() + EDGE_SIZE
	local titleTextWidth = width / 2 - EDGE_SIZE
	local barWidth = width - titleTextWidth

	--sl.name = "UI Alpha"
	sl:SetOrientation( "HORIZONTAL" )
	sl:SetHitRectInsets( 0, 0, -10, 0 )
	SetBackdrop( sl, sliderBackdrop )
	sl:SetThumbTexture( "Interface\\Buttons\\UI-SliderBar-Button-Horizontal" )
	sl.slider = sl
	sl:SetWidth( barWidth )
	sl:SetHeight( height )
	sl:SetPoint( "TOPLEFT", relativeFrame, relativeTo, titleTextWidth + ofsx, ofsy )	
	sl:SetScript( "OnValueChanged", callbackFn )
	sl:SetMinMaxValues( min, max )
	--sl:SetValueStep( 1 )
	sl:SetValue( value )

	titleText:ClearAllPoints()
	titleText:SetPoint( "TOPLEFT", sl, "TOPLEFT", -titleTextWidth, 0 )

	local lowText = getglobal( sl:GetName() .. "Low" )
	lowText:SetFont( "Fonts\\FRIZQT__.TTF", fontSize );
	lowText:SetText( minText )
	lowText:Hide()

	local highText = getglobal( sl:GetName() .. "High" )
	highText:SetFont( "Fonts\\FRIZQT__.TTF", fontSize )
	highText:SetText( maxText )
	highText:Hide()

 	return sl
 end

-- -----------------------------------------------------------------------------
-- HoJ:GetSliderSizeWithText
-- -----------------------------------------------------------------------------
 function HoJ:GetSliderSizeWithText( slider ) 
	local lowHeight = getglobal( slider:GetName() .. "Low" ):GetHeight()
	local highHeight = getglobal( slider:GetName() .. "High" ):GetHeight()
	local textHeight = getglobal( slider:GetName() .. "Text" ):GetHeight()
	local sliderHeight = slider:GetHeight()
	local sliderWidth = slider:GetWidth()
	
	local lowHighHeight = lowHeight
	if ( highHeight > lowHighHeight ) then
		lowHighHeight = highHeight
	end
	
	HoJ:DebugMsg( "sliderWidth = " .. sliderWidth .. ", sliderHeight = " .. sliderHeight .. ", lowHeight = " .. lowHeight .. ", highHeight = " .. highHeight )

	return sliderWidth, sliderHeight + lowHighHeight + textHeight
 end

 -- -----------------------------------------------------------------------------
-- HoJ:SetupCheckboxesForSpellInfos
-- -----------------------------------------------------------------------------
function HoJ:SetupCheckboxesForSpellInfos( spellInfos, checkFrame, prev, anchor, yofs, count )
	if ( spellInfos == nil ) then
		HoJ:Error( "Why you pass nil table, fool?" )
		return 0, nil, nil
	end

	local spellIndex = 0
	local startCount = count

	for key, value in pairs( spellInfos ) do
		if ( value.showCheckbox ) then
			--HoJ:DebugMsg( key .. " is " .. value.name )
			if ( key == nil ) then
				HoJ:DebugMsg( "got nil name for spellInfo id " .. value.id )
			elseif ( value == nil ) then
				HoJ:DebugMsg( "got nil value for spellInfo id " .. value.id )
			elseif ( value.name == nil ) then
				HoJ:DebugMsg( "got nil value.name for spellInfo id " .. value.id )
			else
				prev = HoJ:SetupShowSpellCheckBox( checkFrame, prev, key, "TOPLEFT", anchor, 0, yofs, 10, value, count )
				if ( count == startCount ) then
					anchor = "BOTTOMLEFT"
					yofs = 2
				end
			end
			count = count + 1
		end
		spellIndex = spellIndex + 1
	end

	return count, prev, anchor
end

-- -----------------------------------------------------------------------------
-- HoJ:AddHeadingToScrollList
-- -----------------------------------------------------------------------------
function HoJ:AddHeadingToScrollList( listFrame, prev, anchor, xofs, yofs, fontSize, count, text )
	heading = listFrame:CreateFontString( nil, "ARTWORK" )

	heading:SetFont( "Fonts\\FRIZQT__.TTF", fontSize )
	heading:SetJustifyH( "LEFT" )
	heading:SetJustifyV( "TOP" )
	heading:ClearAllPoints()
	heading:SetTextColor( 1, 1, 1, 1 )
	heading:SetPoint( "TOPLEFT", prev, anchor, 0, yofs )
	heading:SetText( text )
	
	count = count + 1

	return count, heading
end

-- -----------------------------------------------------------------------------
-- HoJ:AddTextToFrame
-- -----------------------------------------------------------------------------
function HoJ:AddTextToFrame( ownerFrame, parentFrame, textAnchor, parentAnchor, xofs, yofs, r, g, b, fontSize, text )
	local fs = ownerFrame:CreateFontString( nil, "ARTWORK" );
	fs:SetFont( "Fonts\\FRIZQT__.TTF", fontSize );
	fs:SetJustifyH( "LEFT" );
	fs:SetJustifyV( "TOP" );
	fs:ClearAllPoints();
	fs:SetTextColor( r, g, b, 1 );
	fs:SetPoint( textAnchor, parentFrame, parentAnchor, xofs, yofs );
	fs:SetText( text );
	return fs
end

-- -----------------------------------------------------------------------------
-- HoJ:SetupAddOnOptions
-- -----------------------------------------------------------------------------
function HoJ:SetupAddOnOptions()
	--HoJ:DebugMsg( "HoJ:SetupAddOnOptions" );
	local panel = CreateFrame( "FRAME", "HoJOptions" );
	--panel.name = "Hammer of Justas";
	panel.name = GetAddOnMetadata( "HammerOfJustas", "Title" );
	panel.parent = nil;
	panel.okay = function ( self ) HoJ:AddonOptions_OnOK( self ) end;
	panel.cancel = function ( self ) HoJ:AddonOptions_OnCancel( self ) end;
	panel.defalt = function ( self ) HoJ:AddonOptions_OnDefault( self ) end;
	panel.refresh = function ( self ) HoJ:AddonOptions_OnRefresh( self ) end;
	InterfaceOptions_AddCategory( panel );

	local panelHeader = panel:CreateFontString( nil, "ARTWORK" );
	panelHeader:SetFont( "Fonts\\FRIZQT__.TTF", 24 );
	panelHeader:SetJustifyH( "LEFT" );
	panelHeader:SetJustifyV( "TOP" );
	panelHeader:ClearAllPoints();
	panelHeader:SetPoint( "TOPLEFT", 16, -16 );
	panelHeader:SetText( "Hammer of Justas v. " .. HoJ:GetVersionString() );

	------------------------------------------------------------
	-- class skills list
	------------------------------------------------------------
	local checklistTitle = panel:CreateFontString( nil, "ARTWORK" )
	checklistTitle:SetFont( "Fonts\\FRIZQT__.TTF", 12 )
	checklistTitle:SetJustifyH( "LEFT" )
	checklistTitle:SetJustifyV( "TOP" )
	checklistTitle:ClearAllPoints()
	checklistTitle:SetTextColor( 1, 1, 1, 1 )
	checklistTitle:SetPoint( "TOPLEFT", panelHeader, "BOTTOMLEFT", 0, -16 )
	checklistTitle:SetText( HoJ._text["Per-Class Settings"] )

	local SCROLL_BORDER_HEIGHT = 24 * 8 + EDGE_SIZE * 2;
	local classScrollBorder = CreateFrame( "FRAME", "classScrollBorder", panel );
	classScrollBorder:SetPoint( "TOPLEFT", checklistTitle, "BOTTOMLEFT", 0, 0 );
	--classScrollBorder:SetPoint( "TOPRIGHT", panel, "TOP", -EDGE_SIZE, 0 );
	classScrollBorder:SetPoint( "BOTTOMRIGHT", panel, "RIGHT", -EDGE_SIZE, 0 );
	SetBackdrop( classScrollBorder, listBackdrop )
	classScrollBorder:Show()

	local classScrollView = CreateFrame( "SCROLLFRAME", "classScrollView", classScrollBorder );
	classScrollView:EnableMouseWheel( true );
	classScrollView:SetScript( "OnMouseWheel", scrollView_OnMouseWheel );
	classScrollView:SetPoint( "TOPLEFT", classScrollBorder, "TOPLEFT", EDGE_SIZE, -EDGE_SIZE );
	classScrollView:SetPoint( "TOPRIGHT", classScrollBorder, "TOPRIGHT", -EDGE_SIZE, -EDGE_SIZE );
	classScrollView:SetPoint( "BOTTOMLEFT", classScrollBorder, "BOTTOMLEFT", EDGE_SIZE,
	EDGE_SIZE );
	classScrollView:SetPoint( "BOTTOMRIGHT", classScrollBorder, "BOTTOMRIGHT", -EDGE_SIZE, EDGE_SIZE );

	local classCheckFrame = CreateFrame( "FRAME", "classCheckFrame", classScrollView );
	classScrollView:SetScrollChild( classCheckFrame );

	classCheckFrame:SetPoint( "TOPLEFT", classScrollView, "TOPLEFT", 0, 0 );
	classCheckFrame:Lower();

	------------------------------------------------------------
	-- paladin skills list
	------------------------------------------------------------
	local YPAD = 2
	local count = 0
	local prev = nil

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, classCheckFrame, "TOPLEFT", 0, 0, 14, count, HoJ._text["Paladin Settings"] )

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, -8, 10, count, HoJ._text["Frame Toggles"] )

	local checkShowTemplarsVerdictFrame = HoJ:SetupCheckBox( classCheckFrame, prev, 
			"checkShowTemplarsVerdict", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ._showTemplarsVerdictFrame, 10, HoJ._text["Show Templars Verdict Frame"] )
	checkShowTemplarsVerdictFrame:SetScript( "OnClick", function ( self ) HoJ:ToggleShowTemplarsVerdictFrame() end )
	checkShowTemplarsVerdictFrame:Show()

	local checkShowHolyPowerFrame = HoJ:SetupCheckBox( classCheckFrame, checkShowTemplarsVerdictFrame, 
			"checkShowHolyPower", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ._showHolyPowerFrame, 10, HoJ._text["Show Holy Power Frame"] )
	checkShowHolyPowerFrame:SetScript( "OnClick", function ( self ) HoJ:ToggleShowHolyPowerFrame() end )
	checkShowHolyPowerFrame:Show()
	
	count = count + 2
	prev = checkShowHolyPowerFrame

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, -8, 10, count, HoJ._text["Spec Toggles"] )

	local checkEnableRetribution = HoJ:SetupCheckBox( classCheckFrame, prev, 
			"checkEnableRetribution", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_PALADIN][HoJ.SPEC_NAME_PALADIN_RETRIBUTION]._enabled, 10, HoJ._text["Enable for Retribution"] )
	checkEnableRetribution:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_PALADIN, HoJ.SPEC_NAME_PALADIN_RETRIBUTION ) end )
	checkEnableRetribution:Show()

	local checkEnableProtPaladin = HoJ:SetupCheckBox( classCheckFrame, checkEnableRetribution, 
			"checkEnableProtPaladin", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_PALADIN][HoJ.SPEC_NAME_PALADIN_PROTECTION]._enabled, 10, HoJ._text["Enable for Protection"] )
	checkEnableProtPaladin:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_PALADIN, HoJ.SPEC_NAME_PALADIN_PROTECTION ) end )
	checkEnableProtPaladin:Show()

	count = count + 2
	prev = checkEnableProtPaladin

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, -8, 10, count, HoJ._text["Skill Toggles"] )

	local anchor = "TOPLEFT"
	count, prev, anchor = HoJ:SetupCheckboxesForSpellInfos( HoJ[HoJ.CLASS_NAME_PALADIN]._spellInfos, classCheckFrame, prev, anchor, -16, count )

	------------------------------------------------------------
	-- warrior skills list
	------------------------------------------------------------
	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, 0, 14, count, HoJ._text["Warrior Settings"] )

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, -8, 10, count, HoJ._text["Spec Toggles"] )

	local checkEnableArms = HoJ:SetupCheckBox( classCheckFrame, prev, 
			"checkEnableArms", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_WARRIOR][HoJ.SPEC_NAME_WARRIOR_ARMS]._enabled, 10, HoJ._text["Enable for Arms"] )
	checkEnableArms:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_WARRIOR, HoJ.SPEC_NAME_WARRIOR_ARMS ) end )
	checkEnableArms:Show()

	local checkEnableFury = HoJ:SetupCheckBox( classCheckFrame, checkEnableArms, 
			"checkEnableFury", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_WARRIOR][HoJ.SPEC_NAME_WARRIOR_FURY]._enabled, 10, HoJ._text["Enable for Fury"] );
	checkEnableFury:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_WARRIOR, HoJ.SPEC_NAME_WARRIOR_FURY ) end )
	checkEnableFury:Show()

	local checkEnableProtWarrior = HoJ:SetupCheckBox( classCheckFrame, checkEnableFury, 
			"checkEnableProtWarrior", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_WARRIOR][HoJ.SPEC_NAME_WARRIOR_PROTECTION]._enabled, 10, HoJ._text["Enable for Protection"] )
	checkEnableProtWarrior:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_WARRIOR, HoJ.SPEC_NAME_WARRIOR_PROTECTION ) end )
	checkEnableProtWarrior:Show()

	count = count + 3
	prev = checkEnableProtWarrior

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, -8, 10, count, HoJ._text["Skill Toggles"] )

	anchor = "TOPLEFT"
	count, prev, anchor = HoJ:SetupCheckboxesForSpellInfos( HoJ[HoJ.CLASS_NAME_WARRIOR]._spellInfos, classCheckFrame, prev, anchor, -16, count )

	------------------------------------------------------------
	-- rogue skills list
	------------------------------------------------------------
	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, 0, 14, count, HoJ._text["Rogue Settings"] )

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, -8, 10, count, HoJ._text["Spec Toggles"] )

	local checkEnableSubtlety = HoJ:SetupCheckBox( classCheckFrame, prev, 
			"checkEnableSubtlety", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_ROGUE][HoJ.SPEC_NAME_ROGUE_SUBTLETY]._enabled, 10, HoJ._text["Enable for Subtlety"] )
			checkEnableSubtlety:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_ROGUE, HoJ.SPEC_NAME_ROGUE_SUBTLETY ) end )
	checkEnableSubtlety:Show()

	local checkEnableAssassination = HoJ:SetupCheckBox( classCheckFrame, checkEnableSubtlety, 
			"checkEnableAssassination", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_ROGUE][HoJ.SPEC_NAME_ROGUE_ASSASSINATION]._enabled, 10, HoJ._text["Enable for Assassination"] )
			checkEnableAssassination:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_ROGUE, HoJ.SPEC_NAME_ROGUE_ASSASSINATION ) end )
	checkEnableAssassination:Show()

	local checkEnableOutlaw = HoJ:SetupCheckBox( classCheckFrame, checkEnableAssassination, 
			"checkEnableOutlaw", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_ROGUE][HoJ.SPEC_NAME_ROGUE_OUTLAW]._enabled, 10, HoJ._text["Enable for Outlaw"] )
			checkEnableOutlaw:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_ROGUE, HoJ.SPEC_NAME_ROGUE_OUTLAW ) end )
	checkEnableOutlaw:Show()

	count = count + 3
	prev = checkEnableOutlaw

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, -8, 10, count, HoJ._text["Skill Toggles"] )

	anchor = "TOPLEFT"
	count, prev, anchor = HoJ:SetupCheckboxesForSpellInfos( HoJ[HoJ.CLASS_NAME_ROGUE]._spellInfos, classCheckFrame, prev, anchor, -16, count )

	------------------------------------------------------------
	-- demon hunter skills list
	------------------------------------------------------------
	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, 0, 14, count, HoJ._text["Demon Hunter Settings"] )

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, -8, 10, count, HoJ._text["Spec Toggles"] )

	local checkEnableHavoc = HoJ:SetupCheckBox( classCheckFrame, prev, 
			"checkEnableHavoc", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_DEMONHUNTER][HoJ.SPEC_NAME_DEMONHUNTER_HAVOC]._enabled, 10, HoJ._text["Enable for Havoc"] )
			checkEnableHavoc:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_DEMONHUNTER, HoJ.SPEC_NAME_DEMONHUNTER_HAVOC ) end )
			checkEnableHavoc:Show()

	count = count + 1
	prev = checkEnableHavoc

	local checkEnableVengeance = HoJ:SetupCheckBox( classCheckFrame, prev, 
			"checkEnableVengeance", "TOPLEFT", "BOTTOMLEFT", 0, 0, 
			HoJ[HoJ.CLASS_NAME_DEMONHUNTER][HoJ.SPEC_NAME_DEMONHUNTER_VENGEANCE]._enabled, 10, HoJ._text["Enable for Vengeance"] );
	checkEnableVengeance:SetScript( "OnClick", 
			function ( self ) HoJ:ToggleEnableForSpec( HoJ.CLASS_NAME_DEMONHUNTER, HoJ.SPEC_NAME_DEMONHUNTER_VENGEANCE ) end )
	checkEnableVengeance:Show()

	count = count + 1
	prev = checkEnableVengeance

	count, prev = HoJ:AddHeadingToScrollList( classCheckFrame, prev, "BOTTOMLEFT", 0, -8, 10, count, HoJ._text["Skill Toggles"] )

	anchor = "TOPLEFT"
	count, prev, anchor = HoJ:SetupCheckboxesForSpellInfos( HoJ[HoJ.CLASS_NAME_DEMONHUNTER]._spellInfos, classCheckFrame, prev, anchor, -16, count )

	------------------------------------------------------------
	-- set the scroll view height
	------------------------------------------------------------
	classScrollView.itemHeight = prev:GetHeight() - YPAD
	local itemsInclassScrollView = 8
	local totalHeight = ( classScrollView.itemHeight ) * ( count - itemsInclassScrollView )
	classCheckFrame:SetSize( 400, totalHeight )
	classScrollView:SetSize( 400, totalHeight )

	local classScrollSlider = CreateFrame( "SLIDER", "classScrollSlider", classScrollView );
	classScrollSlider.name = "classScrollSlider";
	classScrollSlider:SetOrientation( "VERTICAL" );
	classScrollSlider:SetHitRectInsets( 0, 0, -10, 0 );
	SetBackdrop( classScrollSlider, sliderBackdrop );
	classScrollSlider:SetWidth( SCROLLBAR_WIDTH );
	classScrollSlider:SetThumbTexture( "Interface\\Buttons\\UI-SliderBar-Button-Vertical" );
	classScrollSlider.scrollView = classScrollView;
	classScrollSlider.slider = classScrollSlider;
	classScrollSlider:SetPoint( "TOPLEFT", classScrollView, "TOPRIGHT", -SCROLLBAR_WIDTH, 0 );
	classScrollSlider:SetPoint( "BOTTOMLEFT", classScrollView, "BOTTOMRIGHT", -SCROLLBAR_WIDTH, 0 );
	classScrollSlider:SetScript( "OnValueChanged", function ( slider, value ) HoJ:OnScrollValueChanged( slider, value ) end );
	classScrollSlider:SetMinMaxValues( 0, totalHeight );
	classScrollSlider:SetValueStep( 1 );
	classScrollSlider:SetValue( 0 );
	classScrollView.slider = classScrollSlider;

	------------------------------------------------------------
	-- frame toggles
	local frameToggleHeader = HoJ:AddTextToFrame( panel, classScrollBorder, "TOPLEFT", "BOTTOMLEFT", 0, -16, 1, 1, 1, 14, HoJ._text["Global Frame Toggles"] )

	-- add check box for skills bar
	local checkShowCooldownsFrame = HoJ:SetupCheckBox( panel, frameToggleHeader, "checkCooldowns", "TOPLEFT", "BOTTOMLEFT", 
			0, 0, HoJ._showCooldownsFrame, 11, "Show Cooldowns" );
			checkShowCooldownsFrame:SetScript( "OnClick", function ( self ) HoJ:ToggleShowSkillSFrame() end );
			checkShowCooldownsFrame:Show();

	-- add check box for buffs bar
	local checkShowBuffsFrame = HoJ:SetupCheckBox( panel, checkShowCooldownsFrame, "checkBuffs", "TOPLEFT", "TOPLEFT", 
			HoJ:GetCheckWidthWithText( checkShowCooldownsFrame ) + 16, 0, HoJ._showBuffsFrame, 11, "Show Buffs" );
			checkShowBuffsFrame:SetScript( "OnClick", function ( self ) HoJ:ToggleShowBuffsFrame() end );
			checkShowBuffsFrame:Show();

	local checkShowRotationFrame = HoJ:SetupCheckBox( panel, checkShowBuffsFrame, "checkRotation", "TOPLEFT", "TOPLEFT", 
			HoJ:GetCheckWidthWithText( checkShowBuffsFrame ) + 16, 0, HoJ._showRotationFrame, 11, "Show Rotation" );
			checkShowRotationFrame:SetScript( "OnClick", function ( self ) HoJ:ToggleShowRotationFrame() end );
			checkShowRotationFrame:Show();

	local checkShowRotationSecondaryFrame = HoJ:SetupCheckBox( panel, checkShowRotationFrame, "checkRotationSecondary", "TOPLEFT", "TOPLEFT", 
			HoJ:GetCheckWidthWithText( checkShowRotationFrame ) + 16, 0, HoJ._showRotationSecondaryFrame, 11, "Show Secondary Rotation" );
			checkShowRotationSecondaryFrame:SetScript( "OnClick", function ( self ) HoJ:ToggleShowRotationSecondaryFrame() end );
			checkShowRotationSecondaryFrame:Show();	
	
	local checkShowDebugFrame = HoJ:SetupCheckBox( panel, checkShowCooldownsFrame, "checkShowDebug", "TOPLEFT", "BOTTOMLEFT", 
			0, 0, HoJ._showDebugFrame, 11, "Show Debug Frame" );
			checkShowDebugFrame:SetScript( "OnClick", function ( self ) HoJ:ToggleShowDebugFrame() end );
			checkShowDebugFrame:Show();	

	local columnWidth = 180;

	local frameAlphaHeader = HoJ:AddTextToFrame( panel, checkShowDebugFrame, "TOPLEFT", "BOTTOMLEFT", 0, -16, 1, 1, 1, 14, HoJ._text["Frame Alpha"] )

	local miscHeader = HoJ:AddTextToFrame( panel, checkShowDebugFrame, "TOPLEFT", "BOTTOMLEFT", columnWidth + 24, -16, 1, 1, 1, 14, HoJ._text["Miscellaneous"] )


	local alphaSlider = self:AddHorizontalSlider( "uiAlphaSlider", "Global:", panel, frameAlphaHeader,
			"BOTTOMLEFT", 0, -8, columnWidth, 16, 0.1, 1.0, 9, "0.1", "1.0", Clamp( self._globalAlpha, 0.1, 1.0 ),
			function ( alphaSlider, value )
				getglobal( alphaSlider:GetName() .. "Text" ):SetText( HoJ._text["Global"] .. string.format( ": %.2f", value ) )
				HoJ:OnGlobalAlphaChanged( alphaSlider, value ) 
			end 
		)

	local buffsSlider = self:AddHorizontalSlider( "uiBuffsSlider", "Buffs:", panel, frameAlphaHeader,
			"BOTTOMLEFT", 0, -28, columnWidth, 16, 0.1, 1.0, 9, "0.1", "1.0", Clamp( self._buffsAlpha, 0.1, 1.0 ),
			function ( buffsSlider, value ) 
				getglobal( buffsSlider:GetName() .. "Text" ):SetText( HoJ._text["Buffs"] .. string.format( ": %.2f", value ) )
				HoJ:OnBuffsAlphaChanged( buffsSlider, value ) 
			end 
		)

	local rotationSlider = self:AddHorizontalSlider( "uiRotationSlider", "Rotation:", panel, frameAlphaHeader,
			"BOTTOMLEFT", 0, -48, columnWidth, 16, 0.1, 1.0, 9, "0.1", "1.0", Clamp( self._rotationAlpha, 0.1, 1.0 ),
			function ( rotationSlider, value ) 
				getglobal( rotationSlider:GetName() .. "Text" ):SetText( HoJ._text["Rotation"] .. string.format( ": %.2f", value ) )
				HoJ:OnRotationAlphaChanged( rotationSlider, value ) 
			end 
		)

	local rotationSecondarySlider = self:AddHorizontalSlider( "uiRotationSecondarySlider", "Rotation Secondary:", panel, frameAlphaHeader,
			"BOTTOMLEFT", 0, -68, columnWidth, 16, 0.1, 1.0, 9, "0.1", "1.0", Clamp( self._rotationSecondaryAlpha, 0.1, 1.0 ),
			function ( rotationSecondarySlider, value ) 
				getglobal( rotationSecondarySlider:GetName() .. "Text" ):SetText( HoJ._text["Rotation 2"] .. string.format( ": %.2f", value ) )
				HoJ:OnRotationSecondaryAlphaChanged( rotationSecondarySlider, value ) 
			end 
		)

	local cooldownsSlider = self:AddHorizontalSlider( "uiCooldownsSlider", "Cooldowns:", panel, frameAlphaHeader,
			"BOTTOMLEFT", 0, -88, columnWidth, 16, 0.1, 1.0, 9, "0.1", "1.0", Clamp( self._cooldownsAlpha, 0.1, 1.0 ),
			function ( cooldownsSlider, value ) 
				getglobal( cooldownsSlider:GetName() .. "Text" ):SetText( HoJ._text["Cooldowns"] .. string.format( ": %.2f", value ) )
				HoJ:OnCooldownsAlphaChanged( cooldownsSlider, value ) 
			end 
		)

	local hopoSlider = self:AddHorizontalSlider( "uiHoPoSlider", "Holy Power:", panel, frameAlphaHeader,
			"BOTTOMLEFT", 0, -108, columnWidth, 16, 0.1, 1.0, 9, "0.1", "1.0", Clamp( self._holyPowerAlpha, 0.1, 1.0 ),
			function ( hopoSlider, value ) 
				getglobal( hopoSlider:GetName() .. "Text" ):SetText( HoJ._text["Holy Power"] .. string.format( ": %.2f", value ) )
				HoJ:OnHolyPowerAlphaChanged( hopoSlider, value ) 
			end 
		)

	local debugSlider = self:AddHorizontalSlider( "uiDebugSlider", "Debug:", panel, frameAlphaHeader,
			"BOTTOMLEFT", 0, -128, columnWidth, 16, 0.1, 1.0, 9, "0.1", "1.0", Clamp( self._debugAlpha, 0.1, 1.0 ),
			function ( debugSlider, value ) 
				getglobal( debugSlider:GetName() .. "Text" ):SetText( HoJ._text["Debug"] .. string.format( ": %.2f", value ) )
				HoJ:OnDebugAlphaChanged( debugSlider, value ) 
			end 
		)

	local uiScaleSlider = self:AddHorizontalSlider( "uiScaleSlider", "Scale:", panel, miscHeader,
		"BOTTOMLEFT", 0, -8, columnWidth, 16, 0.25, 1.5, 9, "0.1", "1.0", Clamp( HoJ._uiScale, 0.25, 1.5 ),
		function ( uiScaleSlider, value )
			getglobal( uiScaleSlider:GetName() .. "Text" ):SetText( HoJ._text["UI Scale"] .. string.format( ": %.2f", value ) )
			HoJ._uiScale = value
			HoJ_MainFrame:SetScale( HoJ._uiScale ) 
		end 
	)

	classScrollView:Show()
	classCheckFrame:Show()
	classScrollSlider:Show()
	alphaSlider:Show()
end

