-- -----------------------------------------------------------------------------
-- -----------------------------------------------------------------------------
--  Hammer of Justas
--
-- Copyright (C) 2010-2020
-- By Jonathan E. Wright
--
-- FILE: HoJ_WarriorSpellInfos.lua
-- DESC: Spell tables for classes

local addonName, HoJ = ...

-- DEFAULT_CHAT_FRAME:AddMessage( "HoJ_WarriorSpellInfos.lua" )

--[[
Notes:

_cdId:  for spell ranks other than 1, we must reference the rank 1 spell to get the 
        cooldown. This field should refer to the actual spell that goes on cooldown
        when a spell is used.

--]]

-- -------------------------------------------------------------
-- WARRIOR
-- -------------------------------------------------------------
HoJ._warriorSpellInfos = {
    ["globalCooldown"] = {
        id = 61304,
        name = HoJ:GetSpellName( 61304 ),
        rank = HoJ:GetSpellRank( 61304 ),
        icon = HoJ:GetSpellIcon( 61304 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = false,
        showCheckbox = false,
        showCharges = false,
        text = nil,
        minLevel = 1,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_NONE
    },
    ["slam"] = {
        id = 1464,
        name = HoJ:GetSpellName( 1464 ),
        rank = HoJ:GetSpellRank( 1464 ),
        icon = HoJ:GetSpellIcon( 1464 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 1,
        cooldownRemaining = 0,
        _powerGen = -20,
        range = HoJ.RANGE_MELEE
    },
    ["slam2"] = {
        id = 261901,
        name = HoJ:GetSpellName( 261901 ),
        rank = HoJ:GetSpellRank( 261901 ),
        icon = HoJ:GetSpellIcon( 261901 ),
        _cdId = 1464,
        _debugName = "slam2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 20,
        cooldownRemaining = 0,
        _powerGen = -20,
        range = HoJ.RANGE_MELEE
    },
    ["slam3"] = {
        id = 316534,
        name = HoJ:GetSpellName( 316534 ),
        rank = HoJ:GetSpellRank( 316534 ),
        icon = HoJ:GetSpellIcon( 316534 ),
        _cdId = 1464,
        _debugName = "slam3",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 48,
        cooldownRemaining = 0,
        _powerGen = -20,
        range = HoJ.RANGE_MELEE
    },
    ["colossusSmash"] = {
        id = 167105,
        name = HoJ:GetSpellName( 167105 ),
        rank = HoJ:GetSpellRank( 167105 ),
        icon = HoJ:GetSpellIcon( 167105 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 19,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE
    },
    ["colossusSmash2"] = {
        id = 316411,
        name = HoJ:GetSpellName( 316411 ),
        rank = HoJ:GetSpellRank( 316411 ),
        icon = HoJ:GetSpellIcon( 316411 ),
        _cdId = 167105,
        _debugName = "colossusSmash2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 37,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE
    },
    ["colossusSmashBuff"] = { -- this is the buff the warrior gets after using colossus smash
        id = 167105,
        name = HoJ:GetSpellName( 167105 ),
        rank = HoJ:GetSpellRank( 167105 ),
        icon = HoJ:GetSpellIcon( 167105 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = true,
        text = nil,
        minLevel = 19,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _duration = 15,
        _showStacks = true,
    },
    ["colossusSmashDebuff"] = { -- this is the buff the target gets after the warrior uses colossus smash
        id = 208086,
        name = HoJ:GetSpellName( 208086 ),
        rank = HoJ:GetSpellRank( 208086 ),
        icon = HoJ:GetSpellIcon( 208086 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = true,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _duration = 15,
        _showStacks = true,
    },
    ["hamstring"] = {
        id = 1715,
        name = HoJ:GetSpellName( 1715 ),
        rank = HoJ:GetSpellRank( 1715 ),
        icon = HoJ:GetSpellIcon( 1715 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 4,
        cooldownRemaining = 0,
        _powerGen = -10,
        range = HoJ.RANGE_MELEE
    },
    ["victoryRush"] = {
        id = 34428,
        name = HoJ:GetSpellName( 34428 ),
        rank = HoJ:GetSpellRank( 34428 ),
        icon = HoJ:GetSpellIcon( 34428 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 5,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
    },
    ["executeProxyFury"] = {
        id = 280735,
        name = HoJ:GetSpellName( 280735 ),
        rank = HoJ:GetSpellRank( 280735 ),
        icon = HoJ:GetSpellIcon( 280735 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 9,
        cooldownRemaining = 0,
        _powerGen = 8,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY },
    },
    -- when fury OR prior to choosing a spec, this is the base spell for execute
    ["execute"] = {
        id = 5308,
        name = HoJ:GetSpellName( 5308 ),
        rank = HoJ:GetSpellRank( 5308 ),
        icon = HoJ:GetSpellIcon( 5308 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 9,
        cooldownRemaining = 0,
        _powerGen = -20,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
    },
    -- when fury, this is the base spell for execute
    ["executeFury"] = {
        id = 5308,
        name = HoJ:GetSpellName( 5308 ),
        rank = HoJ:GetSpellRank( 5308 ),
        icon = HoJ:GetSpellIcon( 5308 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 10, -- though this is a level 9 spell, you can't spec Fury until 10
        cooldownRemaining = 0,
        _powerGen = -20,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY },
    },
    -- rank 2 execute for fury
    ["execute2Fury"] = {
        id = 316402,
        name = HoJ:GetSpellName( 316402 ),
        rank = HoJ:GetSpellRank( 316402 ),
        icon = HoJ:GetSpellIcon( 316402 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 13,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY },
    },
    -- rank 3 execute for fury
    ["execute3Fury"] = {
        id = 316403,
        name = HoJ:GetSpellName( 316403 ),
        rank = HoJ:GetSpellRank( 316403 ),
        icon = HoJ:GetSpellIcon( 316403 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 18,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY },
    },
    -- rank 4 execute for fury
    ["execute4Fury"] = {
        id = 231827,
        name = HoJ:GetSpellName( 231827 ),
        rank = HoJ:GetSpellRank( 231827 ),
        icon = HoJ:GetSpellIcon( 231827 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 58,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY },
    },
    -- when arms or prot, this is the base spell for execute
    ["executeArmsProt"] = {
        id = 163201,
        name = HoJ:GetSpellName( 163201 ),
        rank = HoJ:GetSpellRank( 163201 ),
        icon = HoJ:GetSpellIcon( 163201 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 9,
        cooldownRemaining = 0,
        _powerGen = 8,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_PROTECTION },
    },
    -- this is the rank 2 spell when Arms or Prot specced
    ["executeArmsProt2"] = {
        id = 316405,
        name = HoJ:GetSpellName( 316405 ),
        rank = HoJ:GetSpellRank( 316405 ),
        icon = HoJ:GetSpellIcon( 316405 ),
        _cdId = 163201,
        _debugName = "execute2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 13,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_PROTECTION },
    },
    -- this is the rank 3 spell when Arms or Prot specced
    ["executeArmsProt3"] = {
        id = 231830,
        name = HoJ:GetSpellName( 231830 ),
        rank = HoJ:GetSpellRank( 231830 ),
        icon = HoJ:GetSpellIcon( 231830 ),
        _cdId = 5308,
        _debugName = "execute3",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 18,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_PROTECTION },
    },
    ["mortalStrike"] = {
        id = 12294,
        name = HoJ:GetSpellName( 12294 ),
        rank = HoJ:GetSpellRank( 12294 ),
        icon = HoJ:GetSpellIcon( 12294 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 10,
        cooldownRemaining = 0,
        _powerGen = -30,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["mortalStrike2"] = {
        id = 261900,
        name = HoJ:GetSpellName( 261900 ),
        rank = HoJ:GetSpellRank( 261900 ),
        icon = HoJ:GetSpellIcon( 261900 ),
        _cdId = 12294,
        _debugName = "mortalStrike2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 44,
        cooldownRemaining = 0,
        _powerGen = -30,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["sweepingStrikes"] = {
        id = 260708,
        name = HoJ:GetSpellName( 260708 ),
        rank = HoJ:GetSpellRank( 260708 ),
        icon = HoJ:GetSpellIcon( 260708 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 22,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _duration = 12.0
    },
    ["sweepingStrikes2"] = {
        id = 316432,
        name = HoJ:GetSpellName( 316432 ),
        rank = HoJ:GetSpellRank( 316432 ),
        icon = HoJ:GetSpellIcon( 316432 ),
        _cdId = 260708,
        _debugName = "sweepingStrikes2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 42,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _duration = 12.0
    },
    ["sweepingStrikes3"] = {
        id = 316433,
        name = HoJ:GetSpellName( 316433 ),
        rank = HoJ:GetSpellRank( 316433 ),
        icon = HoJ:GetSpellIcon( 316433 ),
        _cdId = 260708,
        _debugName = "sweepingStrikes3",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 58,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _duration = 12.0
    },
    ["bloodthirst"] = {
        id = 23881,
        name = HoJ:GetSpellName( 23881 ),
        rank = HoJ:GetSpellRank( 23881 ),
        icon = HoJ:GetSpellIcon( 23881 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 10,
        cooldownRemaining = 0,
        _powerGen = 8,
        range = HoJ.RANGE_MELEE
    },
    ["bloodthirst2"] = {
        id = 316537,
        name = HoJ:GetSpellName( 316537 ),
        rank = HoJ:GetSpellRank( 316537 ),
        icon = HoJ:GetSpellIcon( 316537 ),
        _cdId = 23881,
        _debugName = "bloodthirst2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 48,
        cooldownRemaining = 0,
        _powerGen = 8,
        range = HoJ.RANGE_MELEE
    },
    ["rampage"] = {
        id = 184367,
        name = HoJ:GetSpellName( 184367 ),
        rank = HoJ:GetSpellRank( 184367 ),
        icon = HoJ:GetSpellIcon( 184367 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 19,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["rampage2"] = {
        id = 316412,
        name = HoJ:GetSpellName( 316412 ),
        rank = HoJ:GetSpellRank( 316412 ),
        icon = HoJ:GetSpellIcon( 316412 ),
        _cdId = 184367,
        _debugName = "rampage2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 28,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["taunt"] = {
        id = 355,
        name = HoJ:GetSpellName( 355 ),
        rank = HoJ:GetSpellRank( 355 ),
        icon = HoJ:GetSpellIcon( 355 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 8,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_30_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["heroicThrow"] = {
        id = 57755,
        name = HoJ:GetSpellName( 57755 ),
        rank = HoJ:GetSpellRank( 57755 ),
        icon = HoJ:GetSpellIcon( 57755 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 27,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_30_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
    },
    ["berserkerRage"] = {
        id = 18499,
        name = HoJ:GetSpellName( 18499 ),
        rank = HoJ:GetSpellRank( 18499 ),
        icon = HoJ:GetSpellIcon( 18499 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 29,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
    },
    ["enrage"] = {
        id = 184361,
        name = HoJ:GetSpellName( 184361 ),
        rank = HoJ:GetSpellRank( 184361 ),
        icon = HoJ:GetSpellIcon( 184361 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 10,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["enrage2"] = {
        id = 316424,
        name = HoJ:GetSpellName( 316424 ),
        rank = HoJ:GetSpellRank( 316424 ),
        icon = HoJ:GetSpellIcon( 316424 ),
        _cdId = 184361,
        _debugName = "enrage2",
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 20,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["enrage3"] = {
        id = 316425,
        name = HoJ:GetSpellName( 316425 ),
        rank = HoJ:GetSpellRank( 316425 ),
        icon = HoJ:GetSpellIcon( 316425 ),
        _cdId = 184361,
        _debugName = "enrage3",
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 42,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["furyEnrageBuff"] = {
        id = 184362,
        name = HoJ:GetSpellName( 184362 ),
        rank = HoJ:GetSpellRank( 184362 ),
        icon = HoJ:GetSpellIcon( 184362 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = false,
        showCheckbox = false,
        showCharges = false,
        text = nil,
        minLevel = 10,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF
    },    
    ["ragingBlow"] = {
        id = 85288,
        name = HoJ:GetSpellName( 85288 ),
        rank = HoJ:GetSpellRank( 85288 ),
        icon = HoJ:GetSpellIcon( 85288 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 12,
        cooldownRemaining = 0,
        _powerGen = 12,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["ragingBlow2"] = {
        id = 316452,
        name = HoJ:GetSpellName( 316452 ),
        rank = HoJ:GetSpellRank( 316452 ),
        icon = HoJ:GetSpellIcon( 316452 ),
        _cdId = 85288,
        _debugName = "ragingBlow2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 26,
        cooldownRemaining = 0,
        _powerGen = 12,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["ragingBlow3"] = {
        id = 316453,
        name = HoJ:GetSpellName( 316453 ),
        rank = HoJ:GetSpellRank( 316453 ),
        icon = HoJ:GetSpellIcon( 316453 ),
        _cdId = 85288,
        _debugName = "ragingBlow3",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 49,
        cooldownRemaining = 0,
        _powerGen = 12,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["cleanseToxins"] = {
        id = 213644,
        name = HoJ:GetSpellName( 213644 ),
        rank = HoJ:GetSpellRank( 213644 ),
        icon = HoJ:GetSpellIcon( 213644 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 12,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_40_YARDS,
        _talentSpecs = { HoJ.SPEC_PALADIN_RETRIBUTION }
    },
    ["pummel"] = {
        id = 6552,
        name = HoJ:GetSpellName( 6552 ),
        rank = HoJ:GetSpellRank( 6552 ),
        icon = HoJ:GetSpellIcon( 6552 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 7,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["whirlwind"] = {
        id = 1680,
        name = HoJ:GetSpellName( 1680 ),
        rank = HoJ:GetSpellRank( 1680 ),
        icon = HoJ:GetSpellIcon( 1680 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 9,
        cooldownRemaining = 0,
        _powerGen = -30,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
    },
    ["whirlwind2"] = {
        id = 316435,
        name = HoJ:GetSpellName( 316435 ),
        rank = HoJ:GetSpellRank( 316435 ),
        icon = HoJ:GetSpellIcon( 316435 ),
        _cdId = 1680,
        _debugName = "whirlwind2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 22,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY },
    },
    ["whirlwind3"] = {
        id = 12950,
        name = HoJ:GetSpellName( 12950 ),
        rank = HoJ:GetSpellRank( 12950 ),
        icon = HoJ:GetSpellIcon( 12950 ),
        _cdId = 1680,
        _debugName = "whirlwind3",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 37,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY },
    },
    ["whirlwindBuff"] = {
        id = 85739,
        name = HoJ:GetSpellName( 85739 ),
        rank = HoJ:GetSpellRank( 85739 ),
        icon = HoJ:GetSpellIcon( 85739 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = false,
        showCheckbox = false,
        showCharges = false,
        text = nil,
        minLevel = 40,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _showStacks = true,
    },
    ["charge"] = {
        id = 100,
        name = HoJ:GetSpellName( 100 ),
        rank = HoJ:GetSpellRank( 100 ),
        icon = HoJ:GetSpellIcon( 100 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 2,
        cooldownRemaining = 0,
        _powerGen = 20,
        range = HoJ.RANGE_25_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["heroicLeap"] = {
        id = 6544,
        name = HoJ:GetSpellName( 6544 ),
        rank = HoJ:GetSpellRank( 6544 ),
        icon = HoJ:GetSpellIcon( 6544 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 33,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_40_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["shatteringThrow"] = {
        id = 64382,
        name = HoJ:GetSpellName( 64382 ),
        rank = HoJ:GetSpellRank( 64382 ),
        icon = HoJ:GetSpellIcon( 64382 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 33,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_40_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["piercingHowl"] = {
        id = 12323,
        name = HoJ:GetSpellName( 12323 ),
        rank = HoJ:GetSpellRank( 12323 ),
        icon = HoJ:GetSpellIcon( 12323 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 21,
        cooldownRemaining = 0,
        _powerGen = 15,
        range = HoJ.RANGE_15_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY }
    },
    ["enragedRegeneration"] = {
        id = 184364,
        name = HoJ:GetSpellName( 184364 ),
        rank = HoJ:GetSpellRank( 184364 ),
        icon = HoJ:GetSpellIcon( 184364 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 23,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["enragedRegeneration2"] = {
        id = 316474,
        name = HoJ:GetSpellName( 316474 ),
        rank = HoJ:GetSpellRank( 316474 ),
        icon = HoJ:GetSpellIcon( 316474 ),
        _cdId = 184364,
        _debugName = "enragedRegeneration2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 32,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["battleShout"] = {
        id = 6673,
        name = HoJ:GetSpellName( 6673 ),
        rank = HoJ:GetSpellRank( 6673 ),
        icon = HoJ:GetSpellIcon( 6673 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        buffDurationSeconds = 3600,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 31,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_100_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
    },
    ["recklessness"] = { -- this is also the same ID for the buff
        id = 1719,
        name = HoJ:GetSpellName( 1719 ),
        rank = HoJ:GetSpellRank( 1719 ),
        icon = HoJ:GetSpellIcon( 1719 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 34,
        cooldownRemaining = 0,
        _powerGen = 100,
        range = HoJ.RANGE_SELF,
        _duration = 14
    },
    ["recklessness2"] = { -- this is also the same ID for the buff
        id = 316828,
        name = HoJ:GetSpellName( 316828 ),
        rank = HoJ:GetSpellRank( 316828 ),
        icon = HoJ:GetSpellIcon( 316828 ),
        _cdId = 1719,
        _debugName = "recklessness2",
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 52,
        cooldownRemaining = 0,
        _powerGen = 100,
        range = HoJ.RANGE_SELF,
        _duration = 14
    },
    ["armsBladestorm"] = {
        id = 227847,
        name = HoJ:GetSpellName( 227847 ),
        rank = HoJ:GetSpellRank( 227847 ),
        icon = HoJ:GetSpellIcon( 227847 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 38,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["dieByTheSword"] = {
        id = 118038,
        name = HoJ:GetSpellName( 118038 ),
        rank = HoJ:GetSpellRank( 118038 ),
        icon = HoJ:GetSpellIcon( 118038 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 23,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        talentRow = 6,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
    },
    ["dieByTheSword2"] = {
        id = 315948,
        name = HoJ:GetSpellName( 315948 ),
        rank = HoJ:GetSpellRank( 315948 ),
        icon = HoJ:GetSpellIcon( 315948 ),
        _cdId = 118038,
        _debugName = "dieByTheSword2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 52,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        talentRow = 6,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
    },
    ["overpower"] = {
        id = 7384,
        name = HoJ:GetSpellName( 7384 ),
        rank = HoJ:GetSpellRank( 7384 ),
        icon = HoJ:GetSpellIcon( 7384 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 12,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        talentRow = 6,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _showStacks = true,
    },
    ["overpower2"] = {
        id = 316440,
        name = HoJ:GetSpellName( 316440 ),
        rank = HoJ:GetSpellRank( 316440 ),
        icon = HoJ:GetSpellIcon( 316440 ),
        _debugName = "overpower2",
        _cdId = 7384,
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 28,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        talentRow = 6,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _showStacks = true,
    },
    ["overpower3"] = {
        id = 316441,
        name = HoJ:GetSpellName( 316441 ),
        rank = HoJ:GetSpellRank( 316441 ),
        icon = HoJ:GetSpellIcon( 316441 ),
        _cdId = 7384,
        _debugName = "overpower3",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 49,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        talentRow = 6,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _showStacks = true,
    },
    -- talents
    ["armsSuddenDeath"] = {
        id = 29725,
        name = HoJ:GetSpellName( 29725 ),
        rank = HoJ:GetSpellRank( 29725 ),
        icon = HoJ:GetSpellIcon( 29725 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 15,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        talentRow = 1,
        talentCol = 2,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["armsSuddenDeathBuff"] = {
        id = 52437,
        name = HoJ:GetSpellName( 52437 ),
        rank = HoJ:GetSpellRank( 52437 ),
        icon = HoJ:GetSpellIcon( 52437 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = false,
        showCheckbox = false,
        showCharges = false,
        text = nil,
        minLevel = 1,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
    },
    ["skullSplitter"] = {
        id = 260643,
        name = HoJ:GetSpellName( 260643 ),
        rank = HoJ:GetSpellRank( 260643 ),
        icon = HoJ:GetSpellIcon( 260643 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 15,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        talentRow = 1,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["impendingVictory"] = {
        id = 202168,
        name = HoJ:GetSpellName( 202168 ),
        rank = HoJ:GetSpellRank( 202168 ),
        icon = HoJ:GetSpellIcon( 202168 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = -10,
        range = HoJ.RANGE_MELEE,
        talentRow = 3,
        talentCol = 2,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["stormBolt"] = { -- arms and fury
        id = 107570,
        name = HoJ:GetSpellName( 107570 ),
        rank = HoJ:GetSpellRank( 107570 ),
        icon = HoJ:GetSpellIcon( 107570 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_20_YARDS,
        talentRow = 2,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY }
    },
    ["armsMassacre"] = {
        id = 281001,
        name = HoJ:GetSpellName( 281001 ),
        rank = HoJ:GetSpellRank( 281001 ),
        icon = HoJ:GetSpellIcon( 281001 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 45,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        talentRow = 3,
        talentCol = 1,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["fervorOfBattle"] = {
        id = 202316,
        name = HoJ:GetSpellName( 202316 ),
        rank = HoJ:GetSpellRank( 202316 ),
        icon = HoJ:GetSpellIcon( 202316 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 45,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        talentRow = 3,
        talentCol = 2,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["rend"] = {
        id = 772,
        name = HoJ:GetSpellName( 772 ),
        rank = HoJ:GetSpellRank( 772 ),
        icon = HoJ:GetSpellIcon( 772 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 45,
        cooldownRemaining = 0,
        _powerGen = -30,
        range = HoJ.RANGE_MELEE,
        talentRow = 3,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["rendDebuff"] = {
        id = 772,
        name = HoJ:GetSpellName( 772 ),
        rank = HoJ:GetSpellRank( 772 ),
        icon = HoJ:GetSpellIcon( 772 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = true,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        talentRow = 3,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY },
        _duration = 15,
        _showStacks = true,
    },
    ["furySuddenDeath"] = {
        id = 280721,
        name = HoJ:GetSpellName( 280721 ),
        rank = HoJ:GetSpellRank( 280721 ),
        icon = HoJ:GetSpellIcon( 280721 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        talentRow = 3,
        talentCol = 1,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["furySuddenDeathBuff"] = {
        id = 280776,
        name = HoJ:GetSpellName( 280776 ),
        rank = HoJ:GetSpellRank( 280776 ),
        icon = HoJ:GetSpellIcon( 280776 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = false,
        showCheckbox = false,
        showCharges = false,
        text = nil,
        minLevel = 15,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
    },
    ["onslaught"] = {
        id = 315720,
        name = HoJ:GetSpellName( 315720 ),
        rank = HoJ:GetSpellRank( 315720 ),
        icon = HoJ:GetSpellIcon( 315720 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = 15,
        range = HoJ.RANGE_MELEE,
        talentRow = 3,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY },
    },
    ["shockwave"] = {
        id = 46968,
        name = HoJ:GetSpellName( 46968 ),
        rank = HoJ:GetSpellRank( 46968 ),
        icon = HoJ:GetSpellIcon( 46968 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 21,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_10_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
    },
    ["furyMassacre"] = {
        id = 206315,
        name = HoJ:GetSpellName( 206315 ),
        rank = HoJ:GetSpellRank( 206315 ),
        icon = HoJ:GetSpellIcon( 206315 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        talentRow = 3,
        talentCol = 1,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["intimidatingShout"] = {
        id = 5246,
        name = HoJ:GetSpellName( 5246 ),
        rank = HoJ:GetSpellRank( 5246 ),
        icon = HoJ:GetSpellIcon( 5246 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 39,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS, -- test show this is actually 10 yards
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["menace"] = {
        id = 275338,
        name = HoJ:GetSpellName( 275338 ),
        rank = HoJ:GetSpellRank( 275338 ),
        icon = HoJ:GetSpellIcon( 275338 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 75,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS,
        talentRow = 5,
        talentCol = 1,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["warbreaker"] = {
        id = 262161,
        name = HoJ:GetSpellName( 262161 ),
        rank = HoJ:GetSpellRank( 262161 ),
        icon = HoJ:GetSpellIcon( 262161 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 40,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS,
        talentRow = 5,
        talentCol = 2,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    -- Arms gets Avatar only as a talent
    ["avatarArms"] = {
        id = 107574,
        name = HoJ:GetSpellName( 107574 ),
        rank = HoJ:GetSpellRank( 107574 ),
        icon = HoJ:GetSpellIcon( 107574 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 26,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        talentRow = 6,
        talentCol = 2,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _duration = 20
    },
    -- Protection gets Avatar as a baseline skill
    ["avatar"] = {
        id = 107574,
        name = HoJ:GetSpellName( 107574 ),
        rank = HoJ:GetSpellRank( 107574 ),
        icon = HoJ:GetSpellIcon( 107574 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 26,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _duration = 20
    },
    -- Rank 2 of Avatar for protection
    ["avatar2"] = {
        id = 316438,
        name = HoJ:GetSpellName( 316438 ),
        rank = HoJ:GetSpellRank( 316438 ),
        icon = HoJ:GetSpellIcon( 316438 ),
        _cdId = 107574,
        _debugName = "avatar2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 52,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _duration = 20
    },
    ["deadlyCalm"] = {
        id = 262228,
        name = HoJ:GetSpellName( 262228 ),
        rank = HoJ:GetSpellRank( 262228 ),
        icon = HoJ:GetSpellIcon( 262228 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 90,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        talentRow = 6,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["ravager"] = {
        id = 152277,
        name = HoJ:GetSpellName( 152277 ),
        rank = HoJ:GetSpellRank( 152277 ),
        icon = HoJ:GetSpellIcon( 152277 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 90,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS,
        talentRow = 7,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["siegebreaker"] = {
        id = 280772,
        name = HoJ:GetSpellName( 280772 ),
        rank = HoJ:GetSpellRank( 280772 ),
        icon = HoJ:GetSpellIcon( 280772 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 50,
        cooldownRemaining = 0,
        _powerGen = 10,
        range = HoJ.RANGE_MELEE,
        talentRow = 7,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["bladestorm"] = {
        id = 46924,
        name = HoJ:GetSpellName( 46924 ),
        rank = HoJ:GetSpellRank( 46924 ),
        icon = HoJ:GetSpellIcon( 46924 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 45,
        cooldownRemaining = 0,
        _powerGen = 25,
        range = HoJ.RANGE_8_YARDS,
        talentRow = 6,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    ["dragonRoar"] = {
        id = 118000,
        name = HoJ:GetSpellName( 118000 ),
        rank = HoJ:GetSpellRank( 118000 ),
        icon = HoJ:GetSpellIcon( 118000 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 45,
        cooldownRemaining = 0,
        _powerGen = 10,
        range = HoJ.RANGE_12_YARDS,
        talentRow = 6,
        talentCol = 2,
        _talentSpecs = { HoJ.SPEC_WARRIOR_FURY }
    },
    -- buffs
    ["rallyingCry"] = {
        id = 97462,
        name = HoJ:GetSpellName( 97462 ),
        rank = HoJ:GetSpellRank( 97462 ),
        icon = HoJ:GetSpellIcon( 97462 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        buffDurationSeconds = 600,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 41,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_40_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["victorious"] = {
        id = 32216,
        name = HoJ:GetSpellName( 32216 ),
        rank = HoJ:GetSpellRank( 32216 ),
        icon = HoJ:GetSpellIcon( 32216 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        buffDurationSeconds = 20000,
        isProcd = true,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 80,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_40_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION }
    },
    -- racials
    ["stoneform"] = {
        id = 20594,
        name = HoJ:GetSpellName( 20594 ),
        rank = HoJ:GetSpellRank( 20594 ),
        icon = HoJ:GetSpellIcon( 20594 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        buffDurationSeconds = 600,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 80,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_40_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION }
    },
    -- arms
    ["mortalWoundsDebuff"] = {
        id = 115804,
        name = HoJ:GetSpellName( 115804 ),
        rank = HoJ:GetSpellRank( 115804 ),
        icon = HoJ:GetSpellIcon( 115804 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = false,
        showCheckbox = false,
        showCharges = true,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        talentRow = 3,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS },
        _duration = 10,
        _showStacks = true,
    },
    ["deepWoundsDebuff"] = {
        id = 262115,
        name = HoJ:GetSpellName( 262115 ),
        rank = HoJ:GetSpellRank( 262115 ),
        icon = HoJ:GetSpellIcon( 262115 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = false,
        showCheckbox = false,
        showCharges = true,
        text = nil,
        minLevel = 42,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        talentRow = 3,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _duration = 10,
        _showStacks = true,
    },
    -- protection warrior
    ["shieldBlock"] = {
        id = 2565,
        name = HoJ:GetSpellName( 2565 ),
        rank = HoJ:GetSpellRank( 2565 ),
        icon = HoJ:GetSpellIcon( 2565 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 6,
        cooldownRemaining = 0,
        _powerGen = -30,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = true,
    },
    ["shieldSlam"] = {
        id = 23922,
        name = HoJ:GetSpellName( 23922 ),
        rank = HoJ:GetSpellRank( 23922 ),
        icon = HoJ:GetSpellIcon( 23922 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 3,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["shieldSlam2"] = {
        id = 316523,
        name = HoJ:GetSpellName( 316523 ),
        rank = HoJ:GetSpellRank( 316523 ),
        icon = HoJ:GetSpellIcon( 316523 ),
        _cdId = 23922,
        _debugName = "shieldSlam2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 10,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["shieldSlam3"] = {
        id = 231834,
        name = HoJ:GetSpellName( 231834 ),
        rank = HoJ:GetSpellRank( 231834 ),
        icon = HoJ:GetSpellIcon( 231834 ),
        _cdId = 23922,
        _debugName = "shieldSlam3",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 28,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["shieldSlam4"] = {
        id = 316790,
        name = HoJ:GetSpellName( 316790 ),
        rank = HoJ:GetSpellRank( 316790 ),
        icon = HoJ:GetSpellIcon( 316790 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 44,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["devastate"] = {
        id = 20243,
        name = HoJ:GetSpellName( 20243 ),
        rank = HoJ:GetSpellRank( 20243 ),
        icon = HoJ:GetSpellIcon( 20243 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 14,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["revenge"] = {
        id = 6572,
        name = HoJ:GetSpellName( 6572 ),
        rank = HoJ:GetSpellRank( 6572 ),
        icon = HoJ:GetSpellIcon( 6572 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 12,
        cooldownRemaining = 0,
        _powerGen = 15,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["revengeBuff"] = {
        id = 5302,
        name = HoJ:GetSpellName( 5302 ),
        rank = HoJ:GetSpellRank( 5302 ),
        icon = HoJ:GetSpellIcon( 5302 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = true,
        text = nil,
        minLevel = 0,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _duration = 6,
        _showStacks = false,
    },
    ["shockwave"] = {
        id = 46968,
        name = HoJ:GetSpellName( 46968 ),
        rank = HoJ:GetSpellRank( 46968 ),
        icon = HoJ:GetSpellIcon( 46968 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 0,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_10_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["intervene"] = {
        id = 3411,
        name = HoJ:GetSpellName( 3411 ),
        rank = HoJ:GetSpellRank( 3411 ),
        icon = HoJ:GetSpellIcon( 3411 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = true,
        text = nil,
        minLevel = 43,
        cooldownRemaining = 0,
        _powerGen = 15,
        range = HoJ.RANGE_25_YARDS, -- min 8 yards?
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = true,
    },
    ["thunderClap"] = {
        id = 6343,
        name = HoJ:GetSpellName( 6343 ),
        rank = HoJ:GetSpellRank( 6343 ),
        icon = HoJ:GetSpellIcon( 6343 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 19,
        cooldownRemaining = 0,
        _powerGen = 5,
        range = HoJ.RANGE_8_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["thunderClap2"] = {
        id = 316414,
        name = HoJ:GetSpellName( 316414 ),
        rank = HoJ:GetSpellRank( 316414 ),
        icon = HoJ:GetSpellIcon( 316414 ),
        _cdId = 6343,
        _debugName = "thunderClap2",
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 32,
        cooldownRemaining = 0,
        _powerGen = 5,
        range = HoJ.RANGE_8_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["ignorePain"] = {
        id = 190456,
        name = HoJ:GetSpellName( 190456 ),
        rank = HoJ:GetSpellRank( 190456 ),
        icon = HoJ:GetSpellIcon( 190456 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 17,
        cooldownRemaining = 0,
        _powerGen = -80,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["ignorePain2"] = {
        id = 316778,
        name = HoJ:GetSpellName( 316778 ),
        rank = HoJ:GetSpellRank( 316778 ),
        icon = HoJ:GetSpellIcon( 316778 ),
        _cdId = 190456,
        _debugName = "ignorePain2",
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 27,
        cooldownRemaining = 0,
        _powerGen = -40,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["shieldWall"] = {
        id = 871,
        name = HoJ:GetSpellName( 871 ),
        rank = HoJ:GetSpellRank( 871 ),
        icon = HoJ:GetSpellIcon( 871 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 23,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["shieldWall2"] = {
        id = 316834,
        name = HoJ:GetSpellName( 316834 ),
        rank = HoJ:GetSpellRank( 316834 ),
        icon = HoJ:GetSpellIcon( 316834 ),
        _cdId = 871,
        _debugName = "shieldWall2",
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 58,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["spellReflection"] = {
        id = 23920,
        name = HoJ:GetSpellName( 23920 ),
        rank = HoJ:GetSpellRank( 23920 ),
        icon = HoJ:GetSpellIcon( 23920 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 47,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["challengingShout"] = {
        id = 1161,
        name = HoJ:GetSpellName( 1161 ),
        rank = HoJ:GetSpellRank( 1161 ),
        icon = HoJ:GetSpellIcon( 1161 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_SKILL,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 54,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_10_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS, HoJ.SPEC_WARRIOR_FURY, HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["lastStand"] = {
        id = 12975,
        name = HoJ:GetSpellName( 12975 ),
        rank = HoJ:GetSpellRank( 12975 ),
        icon = HoJ:GetSpellIcon( 12975 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 37,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["demoralizingShout"] = {
        id = 1160,
        name = HoJ:GetSpellName( 1160 ),
        rank = HoJ:GetSpellRank( 1160 ),
        icon = HoJ:GetSpellIcon( 1160 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 34,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_10_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["demoralizingShout2"] = {
        id = 316464,
        name = HoJ:GetSpellName( 316464 ),
        rank = HoJ:GetSpellRank( 316464 ),
        icon = HoJ:GetSpellIcon( 316464 ),
        _cdId = 1160,
        _debugName = "demoralizingShout2",
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 49,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_10_YARDS,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION },
        _showStacks = false,
    },
    ["boomingVoice"] = {
        id = 202743,
        name = HoJ:GetSpellName( 202743 ),
        rank = HoJ:GetSpellRank( 202743 ),
        icon = HoJ:GetSpellIcon( 202743 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 90,
        cooldownRemaining = 0,
        _powerGen = 25,
        range = HoJ.RANGE_12_YARDS,
        talentRow = 6,
        talentCol = 1,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["protImpendingVictory"] = {
        id = 202168,
        name = HoJ:GetSpellName( 202168 ),
        rank = HoJ:GetSpellRank( 202168 ),
        icon = HoJ:GetSpellIcon( 202168 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = -10,
        range = HoJ.RANGE_MELEE,
        talentRow = 1,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["shieldBlockBuff"] = {
        id = 132404,
        name = HoJ:GetSpellName( 132404 ),
        rank = HoJ:GetSpellRank( 132404 ),
        icon = HoJ:GetSpellIcon( 132404 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_BUFF,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 20,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_SELF
    },
    ["protStormBolt"] = {
        id = 107570,
        name = HoJ:GetSpellName( 107570 ),
        rank = HoJ:GetSpellRank( 107570 ),
        icon = HoJ:GetSpellIcon( 107570 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 30,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_20_YARDS,
        talentRow = 5,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION  }
    },
    ["protDragonRoar"] = {
        id = 118000,
        name = HoJ:GetSpellName( 118000 ),
        rank = HoJ:GetSpellRank( 118000 ),
        icon = HoJ:GetSpellIcon( 118000 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 90,
        cooldownRemaining = 0,
        _powerGen = 25,
        range = HoJ.RANGE_12_YARDS,
        talentRow = 3,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["protRavager"] = {
        id = 228920,
        name = HoJ:GetSpellName( 228920 ),
        rank = HoJ:GetSpellRank( 228920 ),
        icon = HoJ:GetSpellIcon( 228920 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 90,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS,
        talentRow = 7,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_PROTECTION }
    },
    ["defensiveStance"] = {
        id = 197690,
        name = HoJ:GetSpellName( 197690 ),
        rank = HoJ:GetSpellRank( 197690 ),
        icon = HoJ:GetSpellIcon( 197690 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 90,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_8_YARDS,
        talentRow = 7,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
    ["cleave"] = {
        id = 845,
        name = HoJ:GetSpellName( 845 ),
        rank = HoJ:GetSpellRank( 845 ),
        icon = HoJ:GetSpellIcon( 845 ),
        spellIndex = -1,
        spellType = HoJ.SPELL_TALENT,
        isProcd = false,
        showOnBar = true,
        showCheckbox = true,
        showCharges = false,
        text = nil,
        minLevel = 90,
        cooldownRemaining = 0,
        _powerGen = 0,
        range = HoJ.RANGE_MELEE,
        talentRow = 5,
        talentCol = 3,
        _talentSpecs = { HoJ.SPEC_WARRIOR_ARMS }
    },
}
